--*- coding: utf-8 -*-
--[[- LHpi static set data
 Predefined set data for LHpi library, Externalized from LHpi library to 
 distinguish mere set data updates (such as needed on release of a new set)
 from code changes. Also, I want to test if two smaller files are easier to edit.
Finally, adding a new set will not require touching the library anymore.

Inspired by and loosely based on "MTG Mint Card.lua" by Goblin Hero, Stromglad1 and "Import Prices.lua" by woogerboy21;
who generously granted permission to "do as I like" with their code;
everything else Copyright (C) 2012-2014 by Christian Harms.
If you want to contact me about the script, try its release thread in http://www.slightlymagic.net/forum/viewforum.php?f=32

@module LHpi.Data
@author Christian Harms
@copyright 2012-2014 Christian Harms except parts by Goblin Hero, Stromglad1 or woogerboy21
@release This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
]]

--[[ CHANGES
v4
added: 235,807,M15,105,106
fixed: 320,490,590,139,787,26,31,30,10,740,390
added lots of TODO markers
]]

--TODO param importsets and nil all others to save memory?

local Data={}
---	data file version
-- @field [parent=#Data] #string version
Data.version = "4"

--[[- "main" function called by Magic Album; just display error and return.
 Called by Magic Album to import prices. Parameters are passed from MA.
 We don't want to call the data file directly.
 
 @function [parent=#global] ImportPrice
 @param #string importfoil	"Y"|"N"|"O"
 @param #table importlangs	{ #number (langid)= #string , ... }
 @param #table importsets	{ #number (setid)= #string , ... }
]]
function ImportPrice( importfoil , importlangs , importsets )
	ma.Log( "Called LHpi.Data instead of site script. Raising error to inform user via dialog box." )
	ma.Log( "LHpi.Data should be in \\lib subdir to prevent this." )
	error( "LHpi.Data-v" .. LHpi.Data.version .. " is a data file. Please select a LHpi-sitescript instead!" )
end -- function ImportPrice

--[[- all possible languages.
 fields are for subtables indexed by #number langid.
 @type Data.languages
 @field [parent=#Data.languages] #number id		(see ..\Database\Languages.txt)
 @field [parent=#Data.languages] #string full	language name
 @field [parent=#Data.languages] #string abbr	3 letter abbreviation
]]
Data.languages = {
	[1]  = {id=1,  full = "English",				abbr="ENG" },
	[2]  = {id=2,  full = "Russian",				abbr="RUS" },
	[3]  = {id=3,  full = "German",					abbr="GER" },
	[4]  = {id=4,  full = "French",					abbr="FRA" },
	[5]  = {id=5,  full = "Italian",				abbr="ITA" },
	[6]  = {id=6,  full = "Portuguese",				abbr="POR" },
	[7]  = {id=7,  full = "Spanish",				abbr="SPA" },
	[8]  = {id=8,  full = "Japanese",				abbr="JPN" },
	[9]  = {id=9,  full = "Simplified Chinese",		abbr="SZH" },
	[10] = {id=10, full = "Traditional Chinese",	abbr="ZHT" },
	[11] = {id=11, full = "Korean",					abbr="KOR" },
	[12] = {id=12, full = "Hebrew",					abbr="HEB" },
	[13] = {id=13, full = "Arabic",					abbr="ARA" },
	[14] = {id=14, full = "Latin",					abbr="LAT" },
	[15] = {id=15, full = "Sanskrit",				abbr="SAN" },
	[16] = {id=16, full = "Ancient Greek",			abbr="GRC" },
}


--[[- site independent set information.
 fields are for subtables indexed by #number setid.
 @type Data.sets
 @field [parent=#Data.sets] #string name		set name (see ..\"Database\Sets.txt").
 @field [parent=#Data.sets] #table cardcount	number of (English) cards in MA database. { reg= #number , tok= #number }.
 @field [parent=#Data.sets] #boolean foilonly	true if set contains (almost) only foil cards.
 @field [parent=#Data.sets] #table variants		default card variant tables. { #string (name)= #table { #string , #table { (#string or false) , ... } } , ... }
 @field [parent=#Data.sets] #table foiltweak	default foiltweak tables. { #string (name)= #table { foil= #boolean } , ... }
 ]]
Data.sets = {
--- not really a seperate subtable, just a bookmark for quick navigation in eclipse.
-- @field [parent=#Data.sets] #table Coresets
Coresets = nil,
[808] = { name="Magic 2015",
	cardcount={ reg = 269+15, tok = 14 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (250)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (251)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (252)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (253)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (254)"]				= { "Island"	, { 1    , false, false, false } },
["Island (255)"]				= { "Island"	, { false, 2    , false, false } },
["Island (256)"]				= { "Island"	, { false, false, 3    , false } },
["Island (257)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (258)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (259)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (260)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (261)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (262)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (263)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (264)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (265)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (266)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (267)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (268)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (269)"]				= { "Forest"	, { false, false, false, 4     } },
["Beast"]					= { "Beast"		, { 1    , 2     } },
["Beast (5)"]				= { "Beast"		, { 1    , false } },--B
["Beast (9)"]				= { "Beast"		, { false, 2     } },--G
["Bestie"]					= { "Bestie"	, { 1    , 2     } },
["Bestie (5)"]				= { "Bestie"	, { 1    , false } },
["Bestie (9)"]				= { "Bestie"	, { false, 2     } },
	},
},
[797] = { name="Magic 2014",
	cardcount={ reg = 249, tok = 13 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (230)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (231)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (232)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (233)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (234)"]				= { "Island"	, { 1    , false, false, false } },
["Island (235)"]				= { "Island"	, { false, 2    , false, false } },
["Island (236)"]				= { "Island"	, { false, false, 3    , false } },
["Island (237)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (238)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (239)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (240)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (241)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (242)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (243)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (244)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (245)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (246)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (247)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (248)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (249)"]				= { "Forest"	, { false, false, false, 4     } },
["Elemental"]					= { "Elemental"	, { 1    , 2     } },
["Elemental (7)"]				= { "Elemental"	, { 1    , false } },
["Elemental (8)"]				= { "Elemental"	, { false, 2     } },
["Elementarwesen"]				= { "Elementarwesen"	, { 1    , 2     } },
["Elementarwesen (7)"]			= { "Elementarwesen"	, { 1    , false } },
["Elementarwesen (8)"]			= { "Elementarwesen"	, { false, 2     } },
	},
},
[788] = { name="Magic 2013",
	cardcount={ reg = 249, tok = 11 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (230)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (231)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (232)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (233)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (234)"]				= { "Island"	, { 1    , false, false, false } },
["Island (235)"]				= { "Island"	, { false, 2    , false, false } },
["Island (236)"]				= { "Island"	, { false, false, 3    , false } },
["Island (237)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (238)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (239)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (240)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (241)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (242)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (243)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (244)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (245)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (246)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (247)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (248)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (249)"]				= { "Forest"	, { false, false, false, 4     } }
	},
},
[779] = { name="Magic 2012",
	cardcount={ reg = 249, tok =  7 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (230)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (231)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (232)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (233)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (234)"]				= { "Island"	, { 1    , false, false, false } },
["Island (235)"]				= { "Island"	, { false, 2    , false, false } },
["Island (236)"]				= { "Island"	, { false, false, 3    , false } },
["Island (237)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (238)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (239)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (240)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (241)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (242)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (243)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (244)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (245)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (246)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (247)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (248)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (249)"]				= { "Forest"	, { false, false, false, 4     } }
	},
},
[770] = { name="Magic 2011",
	cardcount={ reg = 249, tok =  6 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (230)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (231)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (232)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (233)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (234)"]				= { "Island"	, { 1    , false, false, false } },
["Island (235)"]				= { "Island"	, { false, 2    , false, false } },
["Island (236)"]				= { "Island"	, { false, false, 3    , false } },
["Island (237)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (238)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (239)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (240)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (241)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (242)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (243)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (244)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (245)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (246)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (247)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (248)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (249)"]				= { "Forest"	, { false, false, false, 4     } },
["Ooze"]						= { "Ooze"			, { 1    , 2     } },
["Ooze (5)"]					= { "Ooze"			, { 1    , false } },
["Ooze (6)"]					= { "Ooze"			, { false, 2     } },
["Schlammwesen"]				= { "Schlammwesen"	, { 1    , 2     } },
["Schlammwesen (5)"]			= { "Schlammwesen"	, { 1    , false } },
["Schlammwesen (6)"]			= { "Schlammwesen"	, { false, 2     } },
	},
},
[759] = { name="Magic 2010",
	cardcount={ reg = 249, tok =  8 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (230)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (231)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (232)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (233)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (234)"]				= { "Island"	, { 1    , false, false, false } },
["Island (235)"]				= { "Island"	, { false, 2    , false, false } },
["Island (236)"]				= { "Island"	, { false, false, 3    , false } },
["Island (237)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (238)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (239)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (240)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (241)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (242)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (243)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (244)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (245)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (246)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (247)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (248)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (249)"]				= { "Forest"	, { false, false, false, 4     } }
	},
},
[720] = { name="Tenth Edition",
	cardcount={ reg = 384-1, tok =  6 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (364)"]				= { "Plains"	, { 1    , false, false, false } },
["Plains (365)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (366)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (367)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (368)"]				= { "Island"	, { 1    , false, false, false } },
["Island (369)"]				= { "Island"	, { false, 2    , false, false } },
["Island (370)"]				= { "Island"	, { false, false, 3    , false } },
["Island (371)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (372)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (373)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (374)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (375)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (376)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (377)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (378)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (379)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (380)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (381)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (382)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (383)"]				= { "Forest"	, { false, false, false, 4     } }
	},
},
[630] = { name="9th Edition",
	cardcount={ reg = 359, tok =  0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (331)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (332)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (333)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (334)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (335)"]				= { "Island"	, { 1    , false, false, false } },
["Island (336)"]				= { "Island"	, { false, 2    , false, false } },
["Island (337)"]				= { "Island"	, { false, false, 3    , false } },
["Island (338)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (339)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (340)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (341)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (342)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (343)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (344)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (345)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (346)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (347)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (348)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (349)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (350)"]				= { "Forest"	, { false, false, false, 4     } },
	},
},
[550] = { name="8th Edition",
	cardcount={ reg = 357, tok =  0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (331)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (332)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (333)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (334)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (335)"]				= { "Island"	, { 1    , false, false, false } },
["Island (336)"]				= { "Island"	, { false, 2    , false, false } },
["Island (337)"]				= { "Island"	, { false, false, 3    , false } },
["Island (338)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (339)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (340)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (341)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (342)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (343)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (344)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (345)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (346)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (347)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (348)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (349)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (350)"]				= { "Forest"	, { false, false, false, 4     } },
	},
},
[460] = { name="7th Edition",
	cardcount={ reg = 350, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (341)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (342)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (343)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (344)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (332)"]				= { "Island"	, { 1    , false, false, false } },
["Island (333)"]				= { "Island"	, { false, 2    , false, false } },
["Island (334)"]				= { "Island"	, { false, false, 3    , false } },
["Island (335)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (346)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (347)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (348)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (349)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (337)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (338)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (339)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (340)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (328)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (329)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (330)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (331)"]				= { "Forest"	, { false, false, false, 4     } },
	},
},
[360] = { name="6th Edition",
	cardcount={ reg = 350, tok =  0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (331)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (332)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (333)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (334)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (335)"]				= { "Island"	, { 1    , false, false, false } },
["Island (336)"]				= { "Island"	, { false, 2    , false, false } },
["Island (337)"]				= { "Island"	, { false, false, 3    , false } },
["Island (338)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (339)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (340)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (341)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (342)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (343)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (344)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (345)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (346)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (347)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (348)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (349)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (350)"]				= { "Forest"	, { false, false, false, 4     } },
	},
},
[250] = { name="5th Edition",
	cardcount={ reg = 449, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false, false } }, 
["Plains (2)"]					= { "Plains"	, { false, 2    , false, false } },
["Plains (3)"]					= { "Plains"	, { false, false, 3    , false } },
["Plains (4)"]					= { "Plains"	, { false, false, false, 4     } },
["Island (1)"]					= { "Island"	, { 1    , false, false, false } },
["Island (2)"]					= { "Island"	, { false, 2    , false, false } },
["Island (3)"]					= { "Island"	, { false, false, 3    , false } },
["Island (4)"]					= { "Island"	, { false, false, false, 4     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (3)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (4)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (3)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (4)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (1)"]					= { "Forest"	, { 1    , false, false, false } },
["Forest (2)"]					= { "Forest"	, { false, 2    , false, false } },
["Forest (3)"]					= { "Forest"	, { false, false, 3    , false } },
["Forest (4)"]					= { "Forest"	, { false, false, false, 4     } },
	},
},
[180] = { name="4th Edition",
	cardcount={ reg = 378, tok =  0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false } },
["Plains (2)"]					= { "Plains"	, { false, 2    , false } },
["Plains (3)"]					= { "Plains"	, { false, false, 3     } },
["Island (1)"]					= { "Island"	, { 1    , false, false } },
["Island (2)"]					= { "Island"	, { false, 2    , false } },
["Island (3)"]					= { "Island"	, { false, false, 3     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (3)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (3)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (1)"]					= { "Forest"	, { 1    , false, false } },
["Forest (2)"]					= { "Forest"	, { false, 2    , false } },
["Forest (3)"]					= { "Forest"	, { false, false, 3     } },
	},
},
[179] = { name="4th Edition (FBB)", -- Foreign Black Bordered / Limited
	cardcount={ reg = 378, tok =  0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false } },
["Plains (2)"]					= { "Plains"	, { false, 2    , false } },
["Plains (3)"]					= { "Plains"	, { false, false, 3     } },
["Island (1)"]					= { "Island"	, { 1    , false, false } },
["Island (2)"]					= { "Island"	, { false, 2    , false } },
["Island (3)"]					= { "Island"	, { false, false, 3     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (3)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (3)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (1)"]					= { "Forest"	, { 1    , false, false } },
["Forest (2)"]					= { "Forest"	, { false, 2    , false } },
["Forest (3)"]					= { "Forest"	, { false, false, 3     } },
	},
},
[141] = { name="Revised Edition (Summer Magic)",
	cardcount={ reg=306, tok=0, nontr=0, overs=0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false } },
["Plains (2)"]					= { "Plains"	, { false, 2    , false } },
["Plains (3)"]					= { "Plains"	, { false, false, 3     } },
["Island (1)"]					= { "Island"	, { 1    , false, false } },
["Island (2)"]					= { "Island"	, { false, 2    , false } },
["Island (3)"]					= { "Island"	, { false, false, 3     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (3)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (3)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (1)"]					= { "Forest"	, { 1    , false, false } },
["Forest (2)"]					= { "Forest"	, { false, 2    , false } },
["Forest (3)"]					= { "Forest"	, { false, false, 3     } },
	},
},
[140] = { name="Revised Edition",
	cardcount={ reg = 306, tok =  0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false } },
["Plains (2)"]					= { "Plains"	, { false, 2    , false } },
["Plains (3)"]					= { "Plains"	, { false, false, 3     } },
["Island (1)"]					= { "Island"	, { 1    , false, false } },
["Island (2)"]					= { "Island"	, { false, 2    , false } },
["Island (3)"]					= { "Island"	, { false, false, 3     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (3)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (3)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (1)"]					= { "Forest"	, { 1    , false, false } },
["Forest (2)"]					= { "Forest"	, { false, 2    , false } },
["Forest (3)"]					= { "Forest"	, { false, false, 3     } },
	},
},
[139] = { name="Revised Edition (FBB)", -- Foreign Black Bordered / Limited
	cardcount={ reg = 306, tok =  0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false } },
["Plains (2)"]					= { "Plains"	, { false, 2    , false } },
["Plains (3)"]					= { "Plains"	, { false, false, 3     } },
["Island (1)"]					= { "Island"	, { 1    , false, false } },
["Island (2)"]					= { "Island"	, { false, 2    , false } },
["Island (3)"]					= { "Island"	, { false, false, 3     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (3)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (3)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (1)"]					= { "Forest"	, { 1    , false, false } },
["Forest (2)"]					= { "Forest"	, { false, 2    , false } },
["Forest (3)"]					= { "Forest"	, { false, false, 3     } },
	},
},
[110] = { name="Unlimited",
	cardcount={ reg = 302, tok =  0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false } },
["Plains (2)"]					= { "Plains"	, { false, 2    , false } },
["Plains (3)"]					= { "Plains"	, { false, false, 3     } },
["Island (1)"]					= { "Island"	, { 1    , false, false } },
["Island (2)"]					= { "Island"	, { false, 2    , false } },
["Island (3)"]					= { "Island"	, { false, false, 3     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (3)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (3)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (1)"]					= { "Forest"	, { 1    , false, false } },
["Forest (2)"]					= { "Forest"	, { false, 2    , false } },
["Forest (3)"]					= { "Forest"	, { false, false, 3     } },
	},
},
[100] = { name="Beta",
	cardcount={ reg = 302, tok =  0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false } },
["Plains (2)"]					= { "Plains"	, { false, 2    , false } },
["Plains (3)"]					= { "Plains"	, { false, false, 3     } },
["Island (1)"]					= { "Island"	, { 1    , false, false } },
["Island (2)"]					= { "Island"	, { false, 2    , false } },
["Island (3)"]					= { "Island"	, { false, false, 3     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (3)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (3)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (1)"]					= { "Forest"	, { 1    , false, false } },
["Forest (2)"]					= { "Forest"	, { false, 2    , false } },
["Forest (3)"]					= { "Forest"	, { false, false, 3     } },
	},
},
[90]  = { name="Alpha",
	cardcount={ reg = 295, tok =  0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2     } },
["Island"] 						= { "Island" 	, { 1    , 2     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2     } },
["Forest"] 						= { "Forest" 	, { 1    , 2     } },
["Plains (1)"]					= { "Plains"	, { 1    , false } },
["Plains (2)"]					= { "Plains"	, { false, 2     } },
["Island (1)"]					= { "Island"	, { 1    , false } },
["Island (2)"]					= { "Island"	, { false, 2     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2     } },
["Forest (1)"]					= { "Forest"	, { 1    , false } },
["Forest (2)"]					= { "Forest"	, { false, 2     } },
	},
},
--- not really a seperate subtable, just a bookmark for quick navigation in eclipse.
-- @field [parent=#Data.sets] #table Expansions
Expansions = nil,
[806] = { name = "Journey into Nyx",
	cardcount = { reg=165, tok=6},
},
[802] = { name="Born of the Gods",
	cardcount={ reg=165, tok=11 },
	variants={
["Bird"]						= { "Bird"		, { 1    , 2     } },
["Bird (1)"]					= { "Bird"		, { 1    , false } },--White
["Bird (4)"]					= { "Bird"		, { false, 2     } },--Blue
["Vogel"]						= { "Vogel"		, { 1    , 2     } },
["Vogel (1)"]					= { "Vogel"		, { 1    , false } },--White
["Vogel (4)"]					= { "Vogel"		, { false, 2     } },--Blue
	},
},
[800] = { name="Theros",
	cardcount={ reg = 249, tok = 11 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (230)"]				= { "Plains"	, { 1    , false ,false, false } }, 
["Plains (231)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (232)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (233)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (234)"]				= { "Island"	, { 1    , false, false, false } },
["Island (235)"]				= { "Island"	, { false, 2    , false, false } },
["Island (236)"]				= { "Island"	, { false, false, 3    , false } },
["Island (237)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (238)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (239)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (240)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (241)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (242)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (243)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (244)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (245)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (246)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (247)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (248)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (249)"]				= { "Forest"	, { false, false, false, 4     } },
["Soldier"]						= { "Soldier"	, { 1    , 2    , 3     } },
["Soldier (2)"]					= { "Soldier"	, { 1    , false, false } },
["Soldier (3)"]					= { "Soldier"	, { false, 2    , false } },
["Soldier (7)"]					= { "Soldier"	, { false, false, 3     } },--Red
["Soldat"]						= { "Soldat"	, { 1    , 2    , 3     } },
["Soldat (2)"]					= { "Soldat"	, { 1    , false, false } },
["Soldat (3)"]					= { "Soldat"	, { false, 2    , false } },
["Soldat (7)"]					= { "Soldat"	, { false, false, 3     } },
	},
},
[795] = { name="Dragon's Maze",
	cardcount={ reg = 156, tok =  1 },
	variants={}
},
[793] = { name="Gatecrash",
	cardcount={ reg = 249, tok =  8 },
	variants={}
},
[791] = { name="Return to Ravnica",
	cardcount={ reg = 274, tok = 12 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4    , 5     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4    , 5     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4    , 5     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4    , 5     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4    , 5     } },
["Plains (250)"]				= { "Plains"	, { 1    , false, false, false, false } },
["Plains (251)"]				= { "Plains"	, { false, 2    , false, false, false } },
["Plains (252)"]				= { "Plains"	, { false, false, 3    , false, false } },
["Plains (253)"]				= { "Plains"	, { false, false, false, 4    , false } },
["Plains (254)"]				= { "Plains"	, { false, false, false, false, 5     } },
["Island (255)"]				= { "Island"	, { 1    , false, false, false, false } },
["Island (256)"]				= { "Island"	, { false, 2    , false, false, false } },
["Island (257)"] 				= { "Island"	, { false, false, 3    , false, false } },
["Island (258)"]				= { "Island"	, { false, false, false, 4    , false } },
["Island (259)"]				= { "Island"	, { false, false, false, false, 5     } },
["Swamp (260)"]					= { "Swamp" 	, { 1    , false, false, false, false } },
["Swamp (261)"]					= { "Swamp" 	, { false, 2    , false, false, false } },
["Swamp (262)"]					= { "Swamp" 	, { false, false, 3    , false, false } },
["Swamp (263)"]					= { "Swamp" 	, { false, false, false, 4    , false } },
["Swamp (264)"]					= { "Swamp" 	, { false, false, false, false, 5     } },
["Mountain (265)"]				= { "Mountain"	, { 1    , false, false, false, false } },
["Mountain (266)"]				= { "Mountain"	, { false, 2    , false, false, false } },
["Mountain (267)"]				= { "Mountain"	, { false, false, 3    , false, false } },
["Mountain (268)"]				= { "Mountain"	, { false, false, false, 4    , false } },
["Mountain (269)"]				= { "Mountain"	, { false, false, false, false, 5     } },
["Forest (270)"]				= { "Forest"	, { 1    , false, false, false, false } },
["Forest (271)"]				= { "Forest"	, { false, 2    , false, false, false } },
["Forest (272)"]				= { "Forest"	, { false, false, 3    , false, false } },
["Forest (273)"]				= { "Forest"	, { false, false, false, 4    , false } },
["Forest (274)"]				= { "Forest"	, { false, false, false, false, 5     } }
	},
},
[786] = { name="Avacyn Restored",
	cardcount={ reg = 244, tok =  8 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (230)"]				= { "Plains"	, { 1    , false, false } },
["Plains (231)"]				= { "Plains"	, { false, 2    , false } },
["Plains (232)"]				= { "Plains"	, { false, false, 3     } },
["Island (233)"]				= { "Island"	, { 1    , false, false } },
["Island (234)"]				= { "Island"	, { false, 2    , false } },
["Island (235)"]				= { "Island"	, { false, false, 3     } },
["Swamp (236)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (237)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (238)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (239)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (240)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (241)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (242)"]				= { "Forest"	, { 1    , false, false } },
["Forest (243)"]				= { "Forest"	, { false, 2    , false } },
["Forest (244)"]				= { "Forest"	, { false, false, 3     } },
["Human"]						= { "Human"		, { 1    , 2     } },
["Human (2)"]					= { "Human"		, { 1    ,false  } },--White
["Human (7)"]					= { "Human"		, { false, 2     } },--Red
["Spirit"]						= { "Spirit"	, { 1    , 2     } },
["Spirit (3)"]					= { "Spirit"	, { 1    , false } },--White
["Spirit (4)"]					= { "Spirit"	, { false, 2     } },--Blue
["Mensch"]						= { "Mensch"	, { 1    , 2     } },
["Mensch (2)"]					= { "Mensch"	, { 1    ,false  } },
["Mensch (7)"]					= { "Mensch"	, { false, 2     } },
["Geist"]						= { "Geist"		, { 1    , 2     } },
["Geist (3)"]					= { "Geist"		, { 1    , false } },
["Geist (4)"]					= { "Geist"		, { false, 2     } },
	},
},
[784] = { name="Dark Ascension",
	cardcount={ reg = 158, tok =  3 }, 
	variants={}
},
[782] = { name="Innistrad",
	cardcount={ reg = 264, tok = 12 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (250)"]				= { "Plains"	, { 1    , false, false } },
["Plains (251)"]				= { "Plains"	, { false, 2    , false } },
["Plains (252)"]				= { "Plains"	, { false, false, 3     } },
["Island (253)"]				= { "Island"	, { 1    , false, false } },
["Island (254)"]				= { "Island"	, { false, 2    , false } },
["Island (255)"]				= { "Island"	, { false, false, 3     } },
["Swamp (256)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (257)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (258)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (259)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (260)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (261)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (262)"]				= { "Forest"	, { 1    , false, false } },
["Forest (263)"]				= { "Forest"	, { false, 2    , false } },
["Forest (264)"]				= { "Forest"	, { false, false, 3     } },
["Wolf"]						= { "Wolf"		, { 1    , 2     } },
["Wolf (6)"]					= { "Wolf"		, { 1    , false } },--Deathtouch
["Wolf (12)"]					= { "Wolf"		, { false, 2     } },--Green
["Zombie"]						= { "Zombie"	, { 1    , 2    , 3		} },
["Zombie (7)"]					= { "Zombie"	, { 1    , false, false } },
["Zombie (8)"]					= { "Zombie"	, { false, 2    , false } },
["Zombie (9)"]					= { "Zombie"	, { false, false, 3     } },
	},
},
[776] = { name="New Phyrexia",
	cardcount={ reg = 175, tok =  4 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2     } },
["Island"] 						= { "Island" 	, { 1    , 2     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2     } },
["Forest"] 						= { "Forest" 	, { 1    , 2     } },
["Plains (166)"]				= { "Plains"	, { 1    , false } },
["Plains (167)"]				= { "Plains"	, { false, 2     } },
["Island (168)"]				= { "Island"	, { 1    , false } },
["Island (169)"]				= { "Island"	, { false, 2     } },
["Swamp (170)"]					= { "Swamp"		, { 1    , false } },
["Swamp (171)"]					= { "Swamp"		, { false, 2     } },
["Mountain (172)"]				= { "Mountain"	, { 1    , false } },
["Mountain (173)"]				= { "Mountain"	, { false, 2     } },
["Forest (174)"]				= { "Forest"	, { 1    , false } },
["Forest (175)"]				= { "Forest"	, { false, 2     } }
	},
},
[775] = { name="Mirrodin Besieged",
	cardcount={ reg = 155, tok =  5 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2     } },
["Island"] 						= { "Island" 	, { 1    , 2     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2     } },
["Forest"] 						= { "Forest" 	, { 1    , 2     } },
["Plains (146)"]				= { "Plains"	, { 1    , false } },
["Plains (147)"]				= { "Plains"	, { false, 2     } },
["Island (148)"]				= { "Island"	, { 1    , false } },
["Island (149)"]				= { "Island"	, { false, 2     } },
["Swamp (150)"]					= { "Swamp"		, { 1    , false } },
["Swamp (151)"]					= { "Swamp"		, { false, 2     } },
["Mountain (152)"]				= { "Mountain"	, { 1    , false } },
["Mountain (153)"]				= { "Mountain"	, { false, 2     } },
["Forest (154)"]				= { "Forest"	, { 1    , false } },
["Forest (155)"]				= { "Forest"	, { false, 2     } }
	},
},
[773] = { name="Scars of Mirrodin",
	cardcount={ reg = 249, tok =  9 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (230)"]				= { "Plains"	, { 1    , false ,false, false } }, 
["Plains (231)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (232)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (233)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (234)"]				= { "Island"	, { 1    , false, false, false } },
["Island (235)"]				= { "Island"	, { false, 2    , false, false } },
["Island (236)"]				= { "Island"	, { false, false, 3    , false } },
["Island (237)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (238)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (239)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (240)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (241)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (242)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (243)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (244)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (245)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (246)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (247)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (248)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (249)"]				= { "Forest"	, { false, false, false, 4     } },
["Wurm"]						= { "Wurm"		, { 1    , 2     } },
["Wurm (8)"]					= { "Wurm"		, { 1    , false } }, -- Deathtouch
["Wurm (9)"]					= { "Wurm"		, { false, 2     } }, -- Lifelink
["Poison Counter"]				= { "Poison Counter"	, { "*" } },
	},
},
[767] = { name="Rise of the Eldrazi",
	cardcount={ reg = 248, tok =  7 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (229)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (230)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (231)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (232)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (233)"]				= { "Island"	, { 1    , false, false, false } },
["Island (234)"]				= { "Island"	, { false, 2    , false, false } },
["Island (235)"]				= { "Island"	, { false, false, 3    , false } },
["Island (236)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (237)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (238)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (239)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (240)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (241)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (242)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (243)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (244)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (245)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (246)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (247)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (248)"]				= { "Forest"	, { false, false, false, 4     } },
["Eldrazi Spawn"]		 		= { "Eldrazi Spawn"		, { "a"   , "b"   , "c"   } },
["Eldrazi Spawn (1a)"]		 	= { "Eldrazi Spawn"		, { "a"   , false , false } }, -- art:Aleksi Briclot
["Eldrazi Spawn (1b)"]		 	= { "Eldrazi Spawn"		, { false , "b"   , false } }, -- art:Mark Tedin
["Eldrazi Spawn (1c)"]		 	= { "Eldrazi Spawn"		, { false , false , "c"   } }, -- art:Veronique Meignaud
["Eldrazi, Ausgeburt"]			= { "Eldrazi, Ausgeburt", { "a"   , "b"   , "c"   } },
["Eldrazi, Ausgeburt (1a)"]	 	= { "Eldrazi, Ausgeburt", { "a"   , false , false } },
["Eldrazi, Ausgeburt (1b)"]	 	= { "Eldrazi, Ausgeburt", { false , "b"   , false } },
["Eldrazi, Ausgeburt (1c)"]	 	= { "Eldrazi, Ausgeburt", { false , false , "c"   } },
	},
},
[765] = { name="Worldwake",
	cardcount={ reg = 145, tok =  6 },
	variants={}
},
[762] = { name="Zendikar",
	cardcount={ reg = 269-20, tok = 11 }, -- do not count normal-art basic lands
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4    } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (230)"]				= { "Plains"	, { 1    , false, false, false } },
["Plains (231)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (232)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (233)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (234)"]				= { "Island"	, { 1    , false, false, false } },
["Island (235)"]				= { "Island"	, { false, 2    , false, false } },
["Island (236)"]				= { "Island"	, { false, false, 3    , false } },
["Island (237)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (238)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (239)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (240)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (241)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (242)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (243)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (244)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (245)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (246)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (247)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (248)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (249)"]				= { "Forest"	, { false, false, false, 4     } }
	},
},
[758] = { name="Alara Reborn",
	cardcount={ reg = 145, tok =  4 },
	variants={}
},
[756] = { name="Conflux",
	cardcount={ reg = 145, tok =  2 },
	variants={}
},
[754] = { name="Shards of Alara",
	cardcount={ reg = 249, tok = 10 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (230)"]				= { "Plains"	, { 1    , false ,false, false } }, 
["Plains (231)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (232)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (233)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (234)"]				= { "Island"	, { 1    , false, false, false } },
["Island (235)"]				= { "Island"	, { false, 2    , false, false } },
["Island (236)"]				= { "Island"	, { false, false, 3    , false } },
["Island (237)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (238)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (239)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (240)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (241)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (242)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (243)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (244)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (245)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (246)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (247)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (248)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (249)"]				= { "Forest"	, { false, false, false, 4     } }
	},
},
[752] = { name="Eventide",
	cardcount={ reg = 180, tok =  7 },
	variants={}
},
[751] = { name="Shadowmoor",
	cardcount={ reg = 301, tok = 12 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (282)"]				= { "Plains"	, { 1    , false ,false, false } }, 
["Plains (283)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (284)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (285)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (286)"]				= { "Island"	, { 1    , false, false, false } },
["Island (287)"]				= { "Island"	, { false, 2    , false, false } },
["Island (288)"]				= { "Island"	, { false, false, 3    , false } },
["Island (289)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (290)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (291)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (292)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (293)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (294)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (295)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (296)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (297)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (298)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (299)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (300)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (301)"]				= { "Forest"	, { false, false, false, 4     } },
["Elemental"] 					= { "Elemental"		, { 1    , 2     } },
["Elemental (4)"] 				= { "Elemental"		, { 1    , false } },--Red
["Elemental (9)"] 				= { "Elemental"		, { false, 2     } },--Black|Red
["Elf Warrior"]					= { "Elf Warrior"	, { 1    , 2     } },
["Elf Warrior (5)"]				= { "Elf Warrior"	, { 1    , false } },--Green
["Elf Warrior (12)"]			= { "Elf Warrior"	, { false, 2     } },--White|Green
["Elementarwesen"] 				= { "Elementarwesen", { 1    , 2     } },
["Elementarwesen (4)"] 			= { "Elementarwesen", { 1    , false } },
["Elementarwesen (9)"] 			= { "Elementarwesen", { false, 2     } },
["Elf, Krieger"]				= { "Elf, Krieger"	, { 1    , 2     } },
["Elf, Krieger (5)"]			= { "Elf, Krieger"	, { 1    , false } },
["Elf, Krieger (12)"]			= { "Elf, Krieger"	, { false, 2     } },
	},
},
[750] = { name="Morningtide",
	cardcount={ reg = 150, tok =  3 },
	variants={}
},
[730] = { name="Lorwyn",
	cardcount={ reg = 301, tok = 11 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (282)"]				= { "Plains"	, { 1    , false ,false, false } }, 
["Plains (283)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (284)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (285)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (286)"]				= { "Island"	, { 1    , false, false, false } },
["Island (287)"]				= { "Island"	, { false, 2    , false, false } },
["Island (288)"]				= { "Island"	, { false, false, 3    , false } },
["Island (289)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (290)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (291)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (292)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (293)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (294)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (295)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (296)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (297)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (298)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (299)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (300)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (301)"]				= { "Forest"	, { false, false, false, 4     } },
["Elemental"] 					= { "Elemental"		, { 1    , 2     } },
["Elemental (2)"] 				= { "Elemental"		, { 1    , false } },--White
["Elemental (8)"] 				= { "Elemental"		, { false, 2     } },--Green
["Elementarwesen"] 				= { "Elementarwesen", { 1    , 2     } },
["Elementarwesen (2)"] 			= { "Elementarwesen", { 1    , false } },
["Elementarwesen (8)"] 			= { "Elementarwesen", { false, 2     } },
	},
},
[710] = { name="Future Sight",
	cardcount={ reg = 180, tok =  0 },
	variants={}
},
[700] = { name="Planar Chaos",
	cardcount={ reg = 165, tok =  0 },
	variants={}
},
[690] = { name="Time Spiral Timeshifted",
	cardcount={ reg = 121, tok =  0 },
	variants={}
},
[680] = { name="Time Spiral",
	cardcount={ reg = 301, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (282)"]				= { "Plains"	, { 1    , false ,false, false } }, 
["Plains (283)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (284)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (285)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (286)"]				= { "Island"	, { 1    , false, false, false } },
["Island (287)"]				= { "Island"	, { false, 2    , false, false } },
["Island (288)"]				= { "Island"	, { false, false, 3    , false } },
["Island (289)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (290)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (291)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (292)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (293)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (294)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (295)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (296)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (297)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (298)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (299)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (300)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (301)"]				= { "Forest"	, { false, false, false, 4     } },
	},
},
[670] = { name="Coldsnap",
	cardcount={ reg = 155, tok =  0 },
	variants={}
},
[660] = { name="Dissension",
	cardcount={ reg = 180, tok =  0 },
	variants={}
},
[650] = { name="Guildpact",
	cardcount={ reg = 165, tok =  0 },
	variants={}
},
[640] = { name="Ravnica: City of Guilds",
	cardcount={ reg = 306, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (287)"]				= { "Plains"	, { 1    , false ,false, false } }, 
["Plains (288)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (289)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (290)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (291)"]				= { "Island"	, { 1    , false, false, false } },
["Island (292)"]				= { "Island"	, { false, 2    , false, false } },
["Island (293)"]				= { "Island"	, { false, false, 3    , false } },
["Island (294)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (295)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (296)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (297)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (298)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (299)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (300)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (301)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (302)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (303)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (304)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (305)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (306)"]				= { "Forest"	, { false, false, false, 4     } }
	},
},
[620] = { name="Saviors of Kamigawa",
	cardcount={ reg = 165, tok =  0 },
	variants={}
},
[610] = { name="Betrayers of Kamigawa",
	cardcount={ reg = 165, tok =  0 },
	variants={}
},
[590] = { name="Champions of Kamigawa",
	cardcount={ reg = 307, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (287)"]				= { "Plains"	, { 1    , false ,false, false } }, 
["Plains (288)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (289)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (290)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (291)"]				= { "Island"	, { 1    , false, false, false } },
["Island (292)"]				= { "Island"	, { false, 2    , false, false } },
["Island (293)"]				= { "Island"	, { false, false, 3    , false } },
["Island (294)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (295)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (296)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (297)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (298)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (299)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (300)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (301)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (302)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (303)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (304)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (305)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (306)"]				= { "Forest"	, { false, false, false, 4     } },
["Brothers Yamazaki"]			= { "Brothers Yamazaki"	, { "a"  , "b"   } },
["Brothers Yamazaki (160a)"]	= { "Brothers Yamazaki"	, { "a"  , false } },
["Brothers Yamazaki (160b)"]	= { "Brothers Yamazaki"	, { false, "b"   } },
["Yamazaki-Brüder"]				= { "Yamazaki-Brüder"	, { "a"  , "b"   } },
["Yamazaki-Brüder (160a)"]		= { "Yamazaki-Brüder"	, { "a"  , false } },
["Yamazaki-Brüder (160b)"]		= { "Yamazaki-Brüder"	, { false, "b"   } },
	},
},
[580] = { name="Fifth Dawn",
	cardcount={ reg = 165, tok =  0 },
	variants={}
},
[570] = { name="Darksteel",
	cardcount={ reg = 165, tok =  0 },
	variants={}
},
[560] = { name="Mirrodin",
	cardcount={ reg = 306, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (287)"]				= { "Plains"	, { 1    , false ,false, false } }, 
["Plains (288)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (289)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (290)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (291)"]				= { "Island"	, { 1    , false, false, false } },
["Island (292)"]				= { "Island"	, { false, 2    , false, false } },
["Island (293)"]				= { "Island"	, { false, false, 3    , false } },
["Island (294)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (295)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (296)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (297)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (298)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (299)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (300)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (301)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (302)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (303)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (304)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (305)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (306)"]				= { "Forest"	, { false, false, false, 4     } },
	},
},
[540] = { name="Scourge",
	cardcount={ reg = 143, tok =  0 },
	variants={}
},
[530] = { name="Legions",
	cardcount={ reg = 145, tok =  0 },
	variants={}
},
[520] = { name="Onslaught",
	cardcount={ reg = 350, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (331)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (332)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (333)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (334)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (335)"]				= { "Island"	, { 1    , false, false, false } },
["Island (336)"]				= { "Island"	, { false, 2    , false, false } },
["Island (337)"]				= { "Island"	, { false, false, 3    , false } },
["Island (338)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (339)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (340)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (341)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (342)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (343)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (344)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (345)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (346)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (347)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (348)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (349)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (350)"]				= { "Forest"	, { false, false, false, 4     } },
	},
},
[510] = { name="Judgment",
	cardcount={ reg = 143, tok =  0 },
	variants={}
},
[500] = { name="Torment",
	cardcount={ reg = 143, tok =  0 },
	variants={}
},
[480] = { name="Odyssey",
	cardcount={ reg = 350, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (331)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (332)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (333)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (334)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (335)"]				= { "Island"	, { 1    , false, false, false } },
["Island (336)"]				= { "Island"	, { false, 2    , false, false } },
["Island (337)"]				= { "Island"	, { false, false, 3    , false } },
["Island (338)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (339)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (340)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (341)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (342)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (343)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (344)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (345)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (346)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (347)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (348)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (349)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (350)"]				= { "Forest"	, { false, false, false, 4     } },
	},
},
[470] = { name="Apocalypse",
	cardcount={ reg = 143, tok =  0 },
	variants={}
},
[450] = { name="Planeshift",
	cardcount={ reg = 146, tok =  0 },
	variants={
["Ertai, the Corrupted"] 			= { "Ertai, the Corrupted"		, { ""   , false } },
["Ertai, the Corrupted (Alt)"] 		= { "Ertai, the Corrupted"		, { false, "Alt" } },
["Skyship Weatherlight"] 			= { "Skyship Weatherlight"		, { ""   , false } },
["Skyship Weatherlight (Alt)"] 		= { "Skyship Weatherlight"		, { false, "Alt" } },
["Tahngarth, Talruum Hero"] 		= { "Tahngarth, Talruum Hero"	, { ""   , false } },
["Tahngarth, Talruum Hero (Alt)"]	= { "Tahngarth, Talruum Hero"	, { false, "Alt" } },
	},
	foiltweak={
["Ertai, the Corrupted (Alt)"] 		= { foil = true },
["Skyship Weatherlight (Alt)"] 		= { foil = true },
["Tahngarth, Talruum Hero (Alt)"]	= { foil = true },

	}
},
[430] = { name="Invasion",
	cardcount={ reg = 350, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (331)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (332)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (333)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (334)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (335)"]				= { "Island"	, { 1    , false, false, false } },
["Island (336)"]				= { "Island"	, { false, 2    , false, false } },
["Island (337)"]				= { "Island"	, { false, false, 3    , false } },
["Island (338)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (339)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (340)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (341)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (342)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (343)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (344)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (345)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (346)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (347)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (348)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (349)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (350)"]				= { "Forest"	, { false, false, false, 4     } },
	},
},
[420] = { name="Prophecy",
	cardcount={ reg = 143, tok =  0 },
	variants={}
},
[410] = { name="Nemesis",
	cardcount={ reg = 143, tok =  0 },
	variants={}
},
[400] = { name="Mercadian Masques",
	cardcount={ reg = 350, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (331)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (332)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (333)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (334)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (335)"]				= { "Island"	, { 1    , false, false, false } },
["Island (336)"]				= { "Island"	, { false, 2    , false, false } },
["Island (337)"]				= { "Island"	, { false, false, 3    , false } },
["Island (338)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (339)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (340)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (341)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (342)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (343)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (344)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (345)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (346)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (347)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (348)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (349)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (350)"]				= { "Forest"	, { false, false, false, 4     } },
	},
},
[370] = { name="Urza's Destiny",
	cardcount={ reg = 143, tok =  0 },
	variants={}
},
[350] = { name="Urza's Legacy",
	cardcount={ reg = 143, tok =  0 },
	variants={}
},
[330] = { name="Urza's Saga",
	cardcount={ reg = 350, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (331)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (332)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (333)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (334)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (335)"]				= { "Island"	, { 1    , false, false, false } },
["Island (336)"]				= { "Island"	, { false, 2    , false, false } },
["Island (337)"]				= { "Island"	, { false, false, 3    , false } },
["Island (338)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (339)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (340)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (341)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (342)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (343)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (344)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (345)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (346)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (347)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (348)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (349)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (350)"]				= { "Forest"	, { false, false, false, 4     } },
	},
},
[300] = { name="Exodus",
	cardcount={ reg = 143, tok =  0 },
	variants={}
},
[290] = { name="Stronghold",
	cardcount={ reg = 143, tok =  0 },
	variants={}
},
[280] = { name="Tempest",
	cardcount={ reg = 350, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false, false } }, 
["Plains (2)"]					= { "Plains"	, { false, 2    , false, false } },
["Plains (3)"]					= { "Plains"	, { false, false, 3    , false } },
["Plains (4)"]					= { "Plains"	, { false, false, false, 4     } },
["Island (1)"]					= { "Island"	, { 1    , false, false, false } },
["Island (2)"]					= { "Island"	, { false, 2    , false, false } },
["Island (3)"]					= { "Island"	, { false, false, 3    , false } },
["Island (4)"]					= { "Island"	, { false, false, false, 4     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (3)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (4)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (3)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (4)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (1)"]					= { "Forest"	, { 1    , false, false, false } },
["Forest (2)"]					= { "Forest"	, { false, 2    , false, false } },
["Forest (3)"]					= { "Forest"	, { false, false, 3    , false } },
["Forest (4)"]					= { "Forest"	, { false, false, false, 4     } },
	},
},
[270] = { name="Weatherlight",
	cardcount={ reg = 167, tok =  0 },
	variants={}
},
[240] = { name="Visions",
	cardcount={ reg = 167, tok =  0 },
	variants={}
},
[230] = { name="Mirage",
	cardcount={ reg = 350, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false, false } }, 
["Plains (2)"]					= { "Plains"	, { false, 2    , false, false } },
["Plains (3)"]					= { "Plains"	, { false, false, 3    , false } },
["Plains (4)"]					= { "Plains"	, { false, false, false, 4     } },
["Island (1)"]					= { "Island"	, { 1    , false, false, false } },
["Island (2)"]					= { "Island"	, { false, 2    , false, false } },
["Island (3)"]					= { "Island"	, { false, false, 3    , false } },
["Island (4)"]					= { "Island"	, { false, false, false, 4     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (3)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (4)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (3)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (4)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (1)"]					= { "Forest"	, { 1    , false, false, false } },
["Forest (2)"]					= { "Forest"	, { false, 2    , false, false } },
["Forest (3)"]					= { "Forest"	, { false, false, 3    , false } },
["Forest (4)"]					= { "Forest"	, { false, false, false, 4     } },
	},
},
[220] = { name="Alliances",
	cardcount={ reg = 199, tok =  0 },
	variants={
["Aesthir Glider"] 						= { "Aesthir Glider"				, { 1    , 2     } },
["Aesthir Glider (1)"] 					= { "Aesthir Glider"				, { 1    , false } },
["Aesthir Glider (2)"] 					= { "Aesthir Glider"				, { false, 2     } },
	["Aesthirgleiter"] 					= { "Aesthirgleiter"				, { 1    , 2     } },
	["Aesthirgleiter (1)"] 				= { "Aesthirgleiter"				, { 1    , false } },
	["Aesthirgleiter (2)"] 				= { "Aesthirgleiter"				, { false, 2     } },
["Agent of Stromgald"] 					= { "Agent of Stromgald"			, { 1    , 2     } },
["Agent of Stromgald (1)"] 				= { "Agent of Stromgald"			, { 1    , false } },
["Agent of Stromgald (2)"] 				= { "Agent of Stromgald"			, { false, 2     } },
	["Agent der Stromgalder"] 			= { "Agent der Stromgalder"			, { 1    , 2     } },
	["Agent der Stromgalder (1)"] 		= { "Agent der Stromgalder"			, { 1    , false } },
	["Agent der Stromgalder (2)"] 		= { "Agent der Stromgalder"			, { false, 2     } },
["Arcane Denial"] 						= { "Arcane Denial"					, { 1    , 2     } },
["Arcane Denial (1)"] 					= { "Arcane Denial"					, { 1    , false } },
["Arcane Denial (2)"] 					= { "Arcane Denial"					, { false, 2     } },
	["Mysteriöse Ablehnung"]		 	= { "Mysteriöse Ablehnung"			, { 1    , 2     } },
	["Mysteriöse Ablehnung (1)"] 		= { "Mysteriöse Ablehnung"			, { 1    , false } },
	["Mysteriöse Ablehnung (2)"] 		= { "Mysteriöse Ablehnung"			, { false, 2     } },
["Astrolabe"] 							= { "Astrolabe"						, { 1    , 2     } },
["Astrolabe (1)"] 						= { "Astrolabe"						, { 1    , false } },
["Astrolabe (2)"] 						= { "Astrolabe"						, { false, 2     } },
	["Astrolabium"] 					= { "Astrolabium"					, { 1    , 2     } },
	["Astrolabium (1)"] 				= { "Astrolabium"					, { 1    , false } },
	["Astrolabium (2)"] 				= { "Astrolabium"					, { false, 2     } },
["Awesome Presence"] 					= { "Awesome Presence"				, { 1    , 2     } },
["Awesome Presence (1)"] 				= { "Awesome Presence"				, { 1    , false } },
["Awesome Presence (2)"] 				= { "Awesome Presence"				, { false, 2     } },
	["Furchterregende Aura"]		 	= { "Furchterregende Aura"			, { 1    , 2     } },
	["Furchterregende Aura (1)"] 		= { "Furchterregende Aura"			, { 1    , false } },
	["Furchterregende Aura (2)"] 		= { "Furchterregende Aura"			, { false, 2     } },
["Balduvian War-Makers"] 				= { "Balduvian War-Makers"			, { 1    , 2     } },
["Balduvian War-Makers (1)"] 			= { "Balduvian War-Makers"			, { 1    , false } },
["Balduvian War-Makers (2)"] 			= { "Balduvian War-Makers"			, { false, 2     } },
	["Balduvianische Kämpfer"] 			= { "Balduvianische Kämpfer"		, { 1    , 2     } },
	["Balduvianische Kämpfer (1)"] 		= { "Balduvianische Kämpfer"		, { 1    , false } },
	["Balduvianische Kämpfer (2)"] 		= { "Balduvianische Kämpfer"		, { false, 2     } },
["Benthic Explorers"] 					= { "Benthic Explorers"				, { 1    , 2     } },
["Benthic Explorers (1)"] 				= { "Benthic Explorers"				, { 1    , false } },
["Benthic Explorers (2)"] 				= { "Benthic Explorers"				, { false, 2     } },
	["Meeresforscher"] 					= { "Meeresforscher"				, { 1    , 2     } },
	["Meeresforscher (1)"] 				= { "Meeresforscher"				, { 1    , false } },
	["Meeresforscher (2)"] 				= { "Meeresforscher"				, { false, 2     } },
["Bestial Fury"] 						= { "Bestial Fury"					, { 1    , 2     } },
["Bestial Fury (1)"] 					= { "Bestial Fury"					, { 1    , false } },
["Bestial Fury (2)"] 					= { "Bestial Fury"					, { false, 2     } },
	["Kampfinstinkt"] 					= { "Kampfinstinkt"					, { 1    , 2     } },
	["Kampfinstinkt (1)"] 				= { "Kampfinstinkt"					, { 1    , false } },
	["Kampfinstinkt (2)"] 				= { "Kampfinstinkt"					, { false, 2     } },
["Carrier Pigeons"] 					= { "Carrier Pigeons"				, { 1    , 2     } },
["Carrier Pigeons (1)"] 				= { "Carrier Pigeons"				, { 1    , false } },
["Carrier Pigeons (2)"] 				= { "Carrier Pigeons"				, { false, 2     } },
	["Brieftauben"] 					= { "Brieftauben"					, { 1    , 2     } },
	["Brieftauben (1)"] 				= { "Brieftauben"					, { 1    , false } },
	["Brieftauben (2)"] 				= { "Brieftauben"					, { false, 2     } },
["Casting of Bones"] 					= { "Casting of Bones"				, { 1    , 2     } },
["Casting of Bones (1)"] 				= { "Casting of Bones"				, { 1    , false } },
["Casting of Bones (2)"] 				= { "Casting of Bones"				, { false, 2     } },
	["Knochenorakel"] 					= { "Knochenorakel"					, { 1    , 2     } },
	["Knochenorakel (1)"] 				= { "Knochenorakel"					, { 1    , false } },
	["Knochenorakel (2)"] 				= { "Knochenorakel"					, { false, 2     } },
["Deadly Insect"] 						= { "Deadly Insect"					, { 1    , 2     } },
["Deadly Insect (1)"] 					= { "Deadly Insect"					, { 1    , false } },
["Deadly Insect (2)"] 					= { "Deadly Insect"					, { false, 2     } },
	["Killerinsekten"] 					= { "Killerinsekten"				, { 1    , 2     } },
	["Killerinsekten (1)"] 				= { "Killerinsekten"				, { 1    , false } },
	["Killerinsekten (2)"] 				= { "Killerinsekten"				, { false, 2     } },
["Elvish Ranger"] 						= { "Elvish Ranger"					, { 1    , 2     } },
["Elvish Ranger (1)"] 					= { "Elvish Ranger"					, { 1    , false } },
["Elvish Ranger (2)"] 					= { "Elvish Ranger"					, { false, 2     } },
	["Elfenwaldläufer"] 				= { "Elfenwaldläufer"				, { 1    , 2     } },
	["Elfenwaldläufer (1)"] 			= { "Elfenwaldläufer"				, { 1    , false } },
	["Elfenwaldläufer (2)"] 			= { "Elfenwaldläufer"				, { false, 2     } },
["Enslaved Scout"] 						= { "Enslaved Scout"				, { 1    , 2     } },
["Enslaved Scout (1)"] 					= { "Enslaved Scout"				, { 1    , false } },
["Enslaved Scout (2)"] 					= { "Enslaved Scout"				, { false, 2     } },
	["Unterworfener Späher"] 			= { "Unterworfener Späher"			, { 1    , 2     } },
	["Unterworfener Späher (1)"] 		= { "Unterworfener Späher"			, { 1    , false } },
	["Unterworfener Späher (2)"] 		= { "Unterworfener Späher"			, { false, 2     } },
["Errand of Duty"] 						= { "Errand of Duty"				, { 1    , 2     } },
["Errand of Duty (1)"] 					= { "Errand of Duty"				, { 1    , false } },
["Errand of Duty (2)"] 					= { "Errand of Duty"				, { false, 2     } },
	["Ruf der Pflicht"] 				= { "Ruf der Pflicht"				, { 1    , 2     } },
	["Ruf der Pflicht (1)"] 			= { "Ruf der Pflicht"				, { 1    , false } },
	["Ruf der Pflicht (2)"] 			= { "Ruf der Pflicht"				, { false, 2     } },
["False Demise"] 						= { "False Demise"					, { 1    , 2     } },
["False Demise (1)"] 					= { "False Demise"					, { 1    , false } },
["False Demise (2)"] 					= { "False Demise"					, { false, 2     } },
	["Vorgetäuschter Tod"] 				= { "Vorgetäuschter Tod"			, { 1    , 2     } },
	["Vorgetäuschter Tod (1)"] 			= { "Vorgetäuschter Tod"			, { 1    , false } },
	["Vorgetäuschter Tod (2)"] 			= { "Vorgetäuschter Tod"			, { false, 2     } },
["Feast or Famine"] 					= { "Feast or Famine"				, { 1    , 2     } },
["Feast or Famine (1)"] 				= { "Feast or Famine"				, { 1    , false } },
["Feast or Famine (2)"] 				= { "Feast or Famine"				, { false, 2     } },
	["Um Leben und Tod"] 				= { "Um Leben und Tod"				, { 1    , 2     } },
	["Um Leben und Tod (1)"] 			= { "Um Leben und Tod"				, { 1    , false } },
	["Um Leben und Tod (2)"] 			= { "Um Leben und Tod"				, { false, 2     } },
["Foresight"] 							= { "Foresight"						, { 1    , 2     } },
["Foresight (1)"] 						= { "Foresight"						, { 1    , false } },
["Foresight (2)"] 						= { "Foresight"						, { false, 2     } },
	["Vorsehung"] 						= { "Vorsehung"						, { 1    , 2     } },
	["Vorsehung (1)"] 					= { "Vorsehung"						, { 1    , false } },
	["Vorsehung (2)"] 					= { "Vorsehung"						, { false, 2     } },
["Fevered Strength"] 					= { "Fevered Strength"				, { 1    , 2     } },
["Fevered Strength (1)"] 				= { "Fevered Strength"				, { 1    , false } },
["Fevered Strength (2)"] 				= { "Fevered Strength"				, { false, 2     } },
	["Fieberstärke"] 					= { "Fieberstärke"					, { 1    , 2     } },
	["Fieberstärke (1)"] 				= { "Fieberstärke"					, { 1    , false } },
	["Fieberstärke (2)"] 				= { "Fieberstärke"					, { false, 2     } },
["Fyndhorn Druid"] 						= { "Fyndhorn Druid"				, { 1    , 2     } },
["Fyndhorn Druid (1)"] 					= { "Fyndhorn Druid"				, { 1    , false } },
["Fyndhorn Druid (2)"] 					= { "Fyndhorn Druid"				, { false, 2     } },
	["Fyndhorndruide"] 					= { "Fyndhorndruide"				, { 1    , 2     } },
	["Fyndhorndruide (1)"] 				= { "Fyndhorndruide"				, { 1    , false } },
	["Fyndhorndruide (2)"] 				= { "Fyndhorndruide"				, { false, 2     } },
["Gift of the Woods"] 					= { "Gift of the Woods"				, { 1    , 2     } },
["Gift of the Woods (1)"] 				= { "Gift of the Woods"				, { 1    , false } },
["Gift of the Woods (2)"] 				= { "Gift of the Woods"				, { false, 2     } },
	["Geschenk des Waldes"] 			= { "Geschenk des Waldes"			, { 1    , 2     } },
	["Geschenk des Waldes (1)"] 		= { "Geschenk des Waldes"			, { 1    , false } },
	["Geschenk des Waldes (2)"] 		= { "Geschenk des Waldes"			, { false, 2     } },
["Gorilla Berserkers"] 					= { "Gorilla Berserkers"			, { 1    , 2     } },
["Gorilla Berserkers (1)"] 				= { "Gorilla Berserkers"			, { 1    , false } },
["Gorilla Berserkers (2)"] 				= { "Gorilla Berserkers"			, { false, 2     } },
	["Rasende Gorillas"] 				= { "Rasende Gorillas"				, { 1    , 2     } },
	["Rasende Gorillas (1)"] 			= { "Rasende Gorillas"				, { 1    , false } },
	["Rasende Gorillas (2)"] 			= { "Rasende Gorillas"				, { false, 2     } },
["Gorilla Chieftain"] 					= { "Gorilla Chieftain"				, { 1    , 2     } },
["Gorilla Chieftain (1)"] 				= { "Gorilla Chieftain"				, { 1    , false } },
["Gorilla Chieftain (2)"] 				= { "Gorilla Chieftain"				, { false, 2     } },
	["Gorillahäuptling"] 				= { "Gorillahäuptling"				, { 1    , 2     } },
	["Gorillahäuptling (1)"] 			= { "Gorillahäuptling"				, { 1    , false } },
	["Gorillahäuptling (2)"]	 		= { "Gorillahäuptling"				, { false, 2     } },
["Gorilla Shaman"] 						= { "Gorilla Shaman"				, { 1    , 2     } },
["Gorilla Shaman (1)"] 					= { "Gorilla Shaman"				, { 1    , false } },
["Gorilla Shaman (2)"] 					= { "Gorilla Shaman"				, { false, 2     } },
	["Gorillaschamane"] 				= { "Gorillaschamane"				, { 1    , 2     } },
	["Gorillaschamane (1)"] 			= { "Gorillaschamane"				, { 1    , false } },
	["Gorillaschamane (2)"] 			= { "Gorillaschamane"				, { false, 2     } },
["Gorilla War Cry"] 					= { "Gorilla War Cry"				, { 1    , 2     } },
["Gorilla War Cry (1)"] 				= { "Gorilla War Cry"				, { 1    , false } },
["Gorilla War Cry (2)"] 				= { "Gorilla War Cry"				, { false, 2     } },
	["Schlachtruf der Gorillas"]		= { "Schlachtruf der Gorillas"		, { 1    , 2     } },
	["Schlachtruf der Gorillas (1)"] 	= { "Schlachtruf der Gorillas"		, { 1    , false } },
	["Schlachtruf der Gorillas (2)"] 	= { "Schlachtruf der Gorillas"		, { false, 2     } },
["Guerrilla Tactics"] 					= { "Guerrilla Tactics"				, { 1    , 2     } },
["Guerrilla Tactics (1)"] 				= { "Guerrilla Tactics"				, { 1    , false } },
["Guerrilla Tactics (2)"]	 			= { "Guerrilla Tactics"				, { false, 2     } },
	["Guerillataktik"] 					= { "Guerillataktik"				, { 1    , 2     } },
	["Guerillataktik (1)"] 				= { "Guerillataktik"				, { 1    , false } },
	["Guerillataktik (2)"] 				= { "Guerillataktik"				, { false, 2     } },
["Insidious Bookworms"] 				= { "Insidious Bookworms"			, { 1    , 2     } },
["Insidious Bookworms (1)"] 			= { "Insidious Bookworms"			, { 1    , false } },
["Insidious Bookworms (2)"] 			= { "Insidious Bookworms"			, { false, 2     } },
	["Heimtückische Bücherwürmer"]		= { "Heimtückische Bücherwürmer"	, { 1    , 2     } },
	["Heimtückische Bücherwürmer (1)"]	= { "Heimtückische Bücherwürmer"	, { 1    , false } },
	["Heimtückische Bücherwürmer (2)"] 	= { "Heimtückische Bücherwürmer"	, { false, 2     } },
["Kjeldoran Escort"] 					= { "Kjeldoran Escort"				, { 1    , 2     } },
["Kjeldoran Escort (1)"] 				= { "Kjeldoran Escort"				, { 1    , false } },
["Kjeldoran Escort (2)"] 				= { "Kjeldoran Escort"				, { false, 2     } },
	["Kjeldoranische Eskorte"]		 	= { "Kjeldoranische Eskorte"		, { 1    , 2     } },
	["Kjeldoranische Eskorte (1)"] 		= { "Kjeldoranische Eskorte"		, { 1    , false } },
	["Kjeldoranische Eskorte (2)"] 		= { "Kjeldoranische Eskorte"		, { false, 2     } },
["Kjeldoran Pride"] 					= { "Kjeldoran Pride"				, { 1    , 2     } },
["Kjeldoran Pride (1)"] 				= { "Kjeldoran Pride"				, { 1    , false } },
["Kjeldoran Pride (2)"] 				= { "Kjeldoran Pride"				, { false, 2     } },
	["Kjeldors Stolz"] 					= { "Kjeldors Stolz"				, { 1    , 2     } },
	["Kjeldors Stolz (1)"] 				= { "Kjeldors Stolz"				, { 1    , false } },
	["Kjeldors Stolz (2)"] 				= { "Kjeldors Stolz"				, { false, 2     } },
["Lat-Nam's Legacy"] 					= { "Lat-Nam's Legacy"				, { 1    , 2     } },
["Lat-Nam's Legacy (1)"] 				= { "Lat-Nam's Legacy"				, { 1    , false } },
["Lat-Nam's Legacy (2)"] 				= { "Lat-Nam's Legacy"				, { false, 2     } },
	["Lat-Nams Erbe"] 					= { "Lat-Nams Erbe"					, { 1    , 2     } },
	["Lat-Nams Erbe (1)"] 				= { "Lat-Nams Erbe"					, { 1    , false } },
	["Lat-Nams Erbe (2)"] 				= { "Lat-Nams Erbe"					, { false, 2     } },
["Lim-Dûl's High Guard"]	 			= { "Lim-Dûl's High Guard"			, { 1    , 2     } },
["Lim-Dûl's High Guard (1)"] 			= { "Lim-Dûl's High Guard"			, { 1    , false } },
["Lim-Dûl's High Guard (2)"] 			= { "Lim-Dûl's High Guard"			, { false, 2     } },
	["Lim-Dûls Ehrengarde"]	 			= { "Lim-Dûls Ehrengarde"			, { 1    , 2     } },
	["Lim-Dûls Ehrengarde (1)"] 		= { "Lim-Dûls Ehrengarde"			, { 1    , false } },
	["Lim-Dûls Ehrengarde (2)"] 		= { "Lim-Dûls Ehrengarde"			, { false, 2     } },
["Martyrdom"] 							= { "Martyrdom"						, { 1    , 2     } },
["Martyrdom (1)"] 						= { "Martyrdom"						, { 1    , false } },
["Martyrdom (2)"] 						= { "Martyrdom"						, { false, 2     } },
	["Martyrium"] 						= { "Martyrium"						, { 1    , 2     } },
	["Martyrium (1)"] 					= { "Martyrium"						, { 1    , false } },
	["Martyrium (2)"] 					= { "Martyrium"						, { false, 2     } },
["Noble Steeds"] 						= { "Noble Steeds"					, { 1    , 2     } },
["Noble Steeds (1)"] 					= { "Noble Steeds"					, { 1    , false } },
["Noble Steeds (2)"] 					= { "Noble Steeds"					, { false, 2     } },
	["Edle Rösser"] 					= { "Edle Rösser"					, { 1    , 2     } },
	["Edle Rösser (1)"] 				= { "Edle Rösser"					, { 1    , false } },
	["Edle Rösser (2)"] 				= { "Edle Rösser"					, { false, 2     } },
["Phantasmal Fiend"] 					= { "Phantasmal Fiend"				, { 1    , 2     } },
["Phantasmal Fiend (1)"] 				= { "Phantasmal Fiend"				, { 1    , false } },
["Phantasmal Fiend (2)"] 				= { "Phantasmal Fiend"				, { false, 2     } },
	["Traumunhold"] 					= { "Traumunhold"					, { 1    , 2     } },
	["Traumunhold (1)"] 				= { "Traumunhold"					, { 1    , false } },
	["Traumunhold (2)"] 				= { "Traumunhold"					, { false, 2     } },
["Phyrexian Boon"] 						= { "Phyrexian Boon"				, { 1    , 2     } },
["Phyrexian Boon (1)"] 					= { "Phyrexian Boon"				, { 1    , false } },
["Phyrexian Boon (2)"] 					= { "Phyrexian Boon"				, { false, 2     } },
	["Phyrexianischer Segen"]		 	= { "Phyrexianischer Segen"			, { 1    , 2     } },
	["Phyrexianischer Segen (1)"] 		= { "Phyrexianischer Segen"			, { 1    , false } },
	["Phyrexianischer Segen (2)"] 		= { "Phyrexianischer Segen"			, { false, 2     } },
["Phyrexian War Beast"] 				= { "Phyrexian War Beast"			, { 1    , 2     } },
["Phyrexian War Beast (1)"] 			= { "Phyrexian War Beast"			, { 1    , false } },
["Phyrexian War Beast (2)"] 			= { "Phyrexian War Beast"			, { false, 2     } },
	["Phyrexianische Kriegsbestie"]		= { "Phyrexianische Kriegsbestie"	, { 1    , 2     } },
	["Phyrexianische Kriegsbestie (1)"] = { "Phyrexianische Kriegsbestie"	, { 1    , false } },
	["Phyrexianische Kriegsbestie (2)"] = { "Phyrexianische Kriegsbestie"	, { false, 2     } },
["Reprisal"] 							= { "Reprisal"						, { 1    , 2     } },
["Reprisal (1)"] 						= { "Reprisal"						, { 1    , false } },
["Reprisal (2)"] 						= { "Reprisal"						, { false, 2     } },
	["Revolte"] 						= { "Revolte"						, { 1    , 2     } },
	["Revolte (1)"] 					= { "Revolte"						, { 1    , false } },
	["Revolte (2)"] 					= { "Revolte"						, { false, 2     } },
["Royal Herbalist"] 					= { "Royal Herbalist"				, { 1    , 2     } },
["Royal Herbalist (1)"] 				= { "Royal Herbalist"				, { 1    , false } },
["Royal Herbalist (2)"] 				= { "Royal Herbalist"				, { false, 2     } },
	["Königlicher Kräuterkundler"]		= { "Königlicher Kräuterkundler"	, { 1    , 2     } },
	["Königlicher Kräuterkundler (1)"] 	= { "Königlicher Kräuterkundler"	, { 1    , false } },
	["Königlicher Kräuterkundler (2)"] 	= { "Königlicher Kräuterkundler"	, { false, 2     } },
["Reinforcements"] 						= { "Reinforcements"				, { 1    , 2     } },
["Reinforcements (1)"] 					= { "Reinforcements"				, { 1    , false } },
["Reinforcements (2)"] 					= { "Reinforcements"				, { false, 2     } },
	["Verstärkungen"] 					= { "Verstärkungen"					, { 1    , 2     } },
	["Verstärkungen (1)"] 				= { "Verstärkungen"					, { 1    , false } },
	["Verstärkungen (2)"] 				= { "Verstärkungen"					, { false, 2     } },
["Stench of Decay"] 					= { "Stench of Decay"				, { 1    , 2     } },
["Stench of Decay (1)"] 				= { "Stench of Decay"				, { 1    , false } },
["Stench of Decay (2)"] 				= { "Stench of Decay"				, { false, 2     } },
	["Verwesungsgestank"] 				= { "Verwesungsgestank"				, { 1    , 2     } },
	["Verwesungsgestank (1)"] 			= { "Verwesungsgestank"				, { 1    , false } },
	["Verwesungsgestank (2)"] 			= { "Verwesungsgestank"				, { false, 2     } },
["Storm Shaman"]	 					= { "Storm Shaman"					, { 1    , 2     } },
["Storm Shaman (1)"] 					= { "Storm Shaman"					, { 1    , false } },
["Storm Shaman (2)"] 					= { "Storm Shaman"					, { false, 2     } },
	["Sturmschamane"]	 				= { "Sturmschamane"					, { 1    , 2     } },
	["Sturmschamane (1)"] 				= { "Sturmschamane"					, { 1    , false } },
	["Sturmschamane (2)"] 				= { "Sturmschamane"					, { false, 2     } },
["Storm Crow"] 							= { "Storm Crow"					, { 1    , 2     } },
["Storm Crow (1)"] 						= { "Storm Crow"					, { 1    , false } },
["Storm Crow (2)"] 						= { "Storm Crow"					, { false, 2     } },
	["Sturmkrähe"] 						= { "Sturmkrähe"					, { 1    , 2     } },
	["Sturmkrähe (1)"] 					= { "Sturmkrähe"					, { 1    , false } },
	["Sturmkrähe (2)"] 					= { "Sturmkrähe"					, { false, 2     } },
["Soldevi Adnate"]	 					= { "Soldevi Adnate"				, { 1    , 2     } },
["Soldevi Adnate (1)"] 					= { "Soldevi Adnate"				, { 1    , false } },
["Soldevi Adnate (2)"] 					= { "Soldevi Adnate"				, { false, 2     } },
	["Soldevischer Sektierer"]			= { "Soldevischer Sektierer"		, { 1    , 2     } },
	["Soldevischer Sektierer (1)"] 		= { "Soldevischer Sektierer"		, { 1    , false } },
	["Soldevischer Sektierer (2)"] 		= { "Soldevischer Sektierer"		, { false, 2     } },
["Soldevi Heretic"] 					= { "Soldevi Heretic"				, { 1    , 2     } },
["Soldevi Heretic (1)"] 				= { "Soldevi Heretic"				, { 1    , false } },
["Soldevi Heretic (2)"] 				= { "Soldevi Heretic"				, { false, 2     } },
	["Soldevischer Ketzer"] 			= { "Soldevischer Ketzer"			, { 1    , 2     } },
	["Soldevischer Ketzer (1)"] 		= { "Soldevischer Ketzer"			, { 1    , false } },
	["Soldevischer Ketzer (2)"] 		= { "Soldevischer Ketzer"			, { false, 2     } },
["Soldevi Sage"] 						= { "Soldevi Sage"					, { 1    , 2     } },
["Soldevi Sage (1)"] 					= { "Soldevi Sage"					, { 1    , false } },
["Soldevi Sage (2)"] 					= { "Soldevi Sage"					, { false, 2     } },
	["Soldevischer Weiser"] 			= { "Soldevischer Weiser"			, { 1    , 2     } },
	["Soldevischer Weiser (1)"] 		= { "Soldevischer Weiser"			, { 1    , false } },
	["Soldevischer Weiser (2)"] 		= { "Soldevischer Weiser"			, { false, 2     } },
["Soldevi Sentry"] 						= { "Soldevi Sentry"				, { 1    , 2     } },
["Soldevi Sentry (1)"] 					= { "Soldevi Sentry"				, { 1    , false } },
["Soldevi Sentry (2)"] 					= { "Soldevi Sentry"				, { false, 2     } },
	["Soldevischer Wachposten"] 		= { "Soldevischer Wachposten"		, { 1    , 2     } },
	["Soldevischer Wachposten (1)"] 	= { "Soldevischer Wachposten"		, { 1    , false } },
	["Soldevischer Wachposten (2)"] 	= { "Soldevischer Wachposten"		, { false, 2     } },
["Soldevi Steam Beast"] 				= { "Soldevi Steam Beast"			, { 1    , 2     } },
["Soldevi Steam Beast (1)"] 			= { "Soldevi Steam Beast"			, { 1    , false } },
["Soldevi Steam Beast (2)"] 			= { "Soldevi Steam Beast"			, { false, 2     } },
	["Soldevische Dampfmaschine"]		= { "Soldevische Dampfmaschine"		, { 1    , 2     } },
	["Soldevische Dampfmaschine (1)"] 	= { "Soldevische Dampfmaschine"		, { 1    , false } },
	["Soldevische Dampfmaschine (2)"] 	= { "Soldevische Dampfmaschine"		, { false, 2     } },
["Swamp Mosquito"] 						= { "Swamp Mosquito"				, { 1    , 2     } },
["Swamp Mosquito (1)"] 					= { "Swamp Mosquito"				, { 1    , false } },
["Swamp Mosquito (2)"] 					= { "Swamp Mosquito"				, { false, 2     } },
	["Sumpfmoskito"] 					= { "Sumpfmoskito"					, { 1    , 2     } },
	["Sumpfmoskito (1)"] 				= { "Sumpfmoskito"					, { 1    , false } },
	["Sumpfmoskito (2)"] 				= { "Sumpfmoskito"					, { false, 2     } },
["Taste of Paradise"] 					= { "Taste of Paradise"				, { 1    , 2     } },
["Taste of Paradise (1)"] 				= { "Taste of Paradise"				, { 1    , false } },
["Taste of Paradise (2)"] 				= { "Taste of Paradise"				, { false, 2     } },
	["Vorgeschmack des Paradieses"]		= { "Vorgeschmack des Paradieses"	, { 1    , 2     } },
	["Vorgeschmack des Paradieses (1)"] = { "Vorgeschmack des Paradieses"	, { 1    , false } },
	["Vorgeschmack des Paradieses (2)"] = { "Vorgeschmack des Paradieses"	, { false, 2     } },
["Undergrowth"] 						= { "Undergrowth"					, { 1    , 2     } },
["Undergrowth (1)"] 					= { "Undergrowth"					, { 1    , false } },
["Undergrowth (2)"] 					= { "Undergrowth"					, { false, 2     } },
	["Unterholz"] 						= { "Unterholz"						, { 1    , 2     } },
	["Unterholz (1)"] 					= { "Unterholz"						, { 1    , false } },
	["Unterholz (2)"] 					= { "Unterholz"						, { false, 2     } },
["Varchild's Crusader"] 				= { "Varchild's Crusader"			, { 1    , 2     } },
["Varchild's Crusader (1)"] 			= { "Varchild's Crusader"			, { 1    , false } },
["Varchild's Crusader (2)"] 			= { "Varchild's Crusader"			, { false, 2     } },
	["Varchilds Kreuzritter"]		 	= { "Varchilds Kreuzritter"			, { 1    , 2     } },
	["Varchilds Kreuzritter (1)"] 		= { "Varchilds Kreuzritter"			, { 1    , false } },
	["Varchilds Kreuzritter (2)"] 		= { "Varchilds Kreuzritter"			, { false, 2     } },
["Veteran's Voice"] 					= { "Veteran's Voice"				, { 1    , 2     } },
["Veteran's Voice (1)"] 				= { "Veteran's Voice"				, { 1    , false } },
["Veteran's Voice (2)"] 				= { "Veteran's Voice"				, { false, 2     } },
	["Stimme des Veteranen"] 			= { "Stimme des Veteranen"			, { 1    , 2     } },
	["Stimme des Veteranen (1)"] 		= { "Stimme des Veteranen"			, { 1    , false } },
	["Stimme des Veteranen (2)"] 		= { "Stimme des Veteranen"			, { false, 2     } },
["Viscerid Armor"] 						= { "Viscerid Armor"				, { 1    , 2     } },
["Viscerid Armor (1)"] 					= { "Viscerid Armor"				, { 1    , false } },
["Viscerid Armor (2)"] 					= { "Viscerid Armor"				, { false, 2     } },
	["Visceridenpanzer"] 				= { "Visceridenpanzer"				, { 1    , 2     } },
	["Visceridenpanzer (1)"] 			= { "Visceridenpanzer"				, { 1    , false } },
	["Visceridenpanzer (2)"] 			= { "Visceridenpanzer"				, { false, 2     } },
["Whip Vine"] 							= { "Whip Vine"						, { 1    , 2     } },
["Whip Vine (1)"] 						= { "Whip Vine"						, { 1    , false } },
["Whip Vine (2)"] 						= { "Whip Vine"						, { false, 2     } },
	["Kletterranken"] 					= { "Kletterranken"					, { 1    , 2     } },
	["Kletterranken (1)"] 				= { "Kletterranken"					, { 1    , false } },
	["Kletterranken (2)"] 				= { "Kletterranken"					, { false, 2     } },
["Wild Aesthir"] 						= { "Wild Aesthir"					, { 1    , 2     } },
["Wild Aesthir (1)"] 					= { "Wild Aesthir"					, { 1    , false } },
["Wild Aesthir (2)"] 					= { "Wild Aesthir"					, { false, 2     } },
	["Wilder Aesthir"] 					= { "Wilder Aesthir"				, { 1    , 2     } },
	["Wilder Aesthir (1)"] 				= { "Wilder Aesthir"				, { 1    , false } },
	["Wilder Aesthir (2)"] 				= { "Wilder Aesthir"				, { false, 2     } },
["Yavimaya Ancients"] 					= { "Yavimaya Ancients"				, { 1    , 2     } },
["Yavimaya Ancients (1)"] 				= { "Yavimaya Ancients"				, { 1    , false } },
["Yavimaya Ancients (2)"] 				= { "Yavimaya Ancients"				, { false, 2     } },
	["Ahnen aus Yavimaya"] 				= { "Ahnen aus Yavimaya"			, { 1    , 2     } },
	["Ahnen aus Yavimaya (1)"] 			= { "Ahnen aus Yavimaya"			, { 1    , false } },
	["Ahnen aus Yavimaya (2)"] 			= { "Ahnen aus Yavimaya"			, { false, 2     } },
	},
},
[210] = { name="Homelands",
	cardcount={ reg = 140, tok =  0 },
	variants={
["Abbey Matron"] 					= { "Abbey Matron"				, { 1    , 2     } },
["Abbey Matron (1)"] 				= { "Abbey Matron"				, { 1    , false } },
["Abbey Matron (2)"] 				= { "Abbey Matron"				, { false, 2     } },
	["Oberin der Abtei"] 			= { "Oberin der Abtei"			, { 1    , 2     } },
	["Oberin der Abtei (1)"] 		= { "Oberin der Abtei"			, { 1    , false } },
	["Oberin der Abtei (2)"] 		= { "Oberin der Abtei"			, { false, 2     } },
["Aliban's Tower"] 					= { "Aliban's Tower"			, { 1    , 2     } },
["Aliban's Tower (1)"] 				= { "Aliban's Tower"			, { 1    , false } },
["Aliban's Tower (2)"] 				= { "Aliban's Tower"			, { false, 2     } },
	["Armax' Turm"] 				= { "Armax' Turm"				, { 1    , 2     } },
	["Armax' Turm (1)"] 			= { "Armax' Turm"				, { 1    , false } },
	["Armax' Turm (2)"] 			= { "Armax' Turm"				, { false, 2     } },
["Ambush Party"] 					= { "Ambush Party"				, { 1    , 2     } },
["Ambush Party (1)"] 				= { "Ambush Party"				, { 1    , false } },
["Ambush Party (2)"] 				= { "Ambush Party"				, { false, 2     } },
	["Lauernde Räuber"] 			= { "Lauernde Räuber"			, { 1    , 2     } },
	["Lauernde Räuber (1)"] 		= { "Lauernde Räuber"			, { 1    , false } },
	["Lauernde Räuber (2)"] 		= { "Lauernde Räuber"			, { false, 2     } },
["Anaba Bodyguard"] 				= { "Anaba Bodyguard"			, { 1    , 2     } },
["Anaba Bodyguard (1)"] 			= { "Anaba Bodyguard"			, { 1    , false } },
["Anaba Bodyguard (2)"] 			= { "Anaba Bodyguard"			, { false, 2     } },
	["Anaba-Leibwächter"] 			= { "Anaba-Leibwächter"			, { 1    , 2     } },
	["Anaba-Leibwächter (1)"] 		= { "Anaba-Leibwächter"			, { 1    , false } },
	["Anaba-Leibwächter (2)"] 		= { "Anaba-Leibwächter"			, { false, 2     } },
["Anaba Shaman"] 					= { "Anaba Shaman"				, { 1    , 2     } },
["Anaba Shaman (1)"] 				= { "Anaba Shaman"				, { 1    , false } },
["Anaba Shaman (2)"] 				= { "Anaba Shaman"				, { false, 2     } },
	["Anaba-Schamane"] 				= { "Anaba-Schamane"			, { 1    , 2     } },
	["Anaba-Schamane (1)"] 			= { "Anaba-Schamane"			, { 1    , false } },
	["Anaba-Schamane (2)"] 			= { "Anaba-Schamane"			, { false, 2     } },
["Aysen Bureaucrats"] 				= { "Aysen Bureaucrats"			, { 1    , 2     } },
["Aysen Bureaucrats (1)"] 			= { "Aysen Bureaucrats"			, { 1    , false } },
["Aysen Bureaucrats (2)"] 			= { "Aysen Bureaucrats"			, { false, 2     } },
	["Aysenischer Bürokrat"] 		= { "Aysenischer Bürokrat"		, { 1    , 2     } },
	["Aysenischer Bürokrat (1)"] 	= { "Aysenischer Bürokrat"		, { 1    , false } },
	["Aysenischer Bürokrat (2)"] 	= { "Aysenischer Bürokrat"		, { false, 2     } },
["Carapace"] 						= { "Carapace"					, { 1    , 2     } },
["Carapace (1)"] 					= { "Carapace"					, { 1    , false } },
["Carapace (2)"] 					= { "Carapace"					, { false, 2     } },
	["Rückenpanzer"] 				= { "Rückenpanzer"				, { 1    , 2     } },
	["Rückenpanzer (1)"] 			= { "Rückenpanzer"				, { 1    , false } },
	["Rückenpanzer (2)"] 			= { "Rückenpanzer"				, { false, 2     } },
["Cemetery Gate"] 					= { "Cemetery Gate"				, { 1    , 2     } },
["Cemetery Gate (1)"] 				= { "Cemetery Gate"				, { 1    , false } },
["Cemetery Gate (2)"] 				= { "Cemetery Gate"				, { false, 2     } },
	["Friedhofspforte"]	 			= { "Friedhofspforte"			, { 1    , 2     } },
	["Friedhofspforte (1)"] 		= { "Friedhofspforte"			, { 1    , false } },
	["Friedhofspforte (2)"] 		= { "Friedhofspforte"			, { false, 2     } },
["Dark Maze"] 						= { "Dark Maze"					, { 1    , 2     } },
["Dark Maze (1)"] 					= { "Dark Maze"					, { 1    , false } },
["Dark Maze (2)"] 					= { "Dark Maze"					, { false, 2     } },
	["Dunkler Irrgarten"] 			= { "Dunkler Irrgarten"			, { 1    , 2     } },
	["Dunkler Irrgarten (1)"] 		= { "Dunkler Irrgarten"			, { 1    , false } },
	["Dunkler Irrgarten (2)"] 		= { "Dunkler Irrgarten"			, { false, 2     } },
["Dry Spell"] 						= { "Dry Spell"					, { 1    , 2     } },
["Dry Spell (1)"] 					= { "Dry Spell"					, { 1    , false } },
["Dry Spell (2)"] 					= { "Dry Spell"					, { false, 2     } },
	["Trockenheit"]					= { "Trockenheit"				, { 1    , 2     } },
	["Trockenheit (1)"] 			= { "Trockenheit"				, { 1    , false } },
	["Trockenheit (2)"] 			= { "Trockenheit"				, { false, 2     } },
["Dwarven Trader"] 					= { "Dwarven Trader"			, { 1    , 2     } },
["Dwarven Trader (1)"] 				= { "Dwarven Trader"			, { 1    , false } },
["Dwarven Trader (2)"] 				= { "Dwarven Trader"			, { false, 2     } },
	["Zwergenkaufmann"]	 			= { "Zwergenkaufmann"			, { 1    , 2     } },
	["Zwergenkaufmann (1)"] 		= { "Zwergenkaufmann"			, { 1    , false } },
	["Zwergenkaufmann (2)"] 		= { "Zwergenkaufmann"			, { false, 2     } },
["Feast of the Unicorn"] 			= { "Feast of the Unicorn"		, { 1    , 2     } },
["Feast of the Unicorn (1)"] 		= { "Feast of the Unicorn"		, { 1    , false } },
["Feast of the Unicorn (2)"] 		= { "Feast of the Unicorn"		, { false, 2     } },
	["Einhornschlachtfest"] 		= { "Einhornschlachtfest"		, { 1    , 2     } },
	["Einhornschlachtfest (1)"] 	= { "Einhornschlachtfest"		, { 1    , false } },
	["Einhornschlachtfest (2)"] 	= { "Einhornschlachtfest"		, { false, 2     } },
["Folk of An-Havva"] 				= { "Folk of An-Havva"			, { 1    , 2     } },
["Folk of An-Havva (1)"] 			= { "Folk of An-Havva"			, { 1    , false } },
["Folk of An-Havva (2)"] 			= { "Folk of An-Havva"			, { false, 2     } },
	["Bewohner von An-Havva"]	 	= { "Bewohner von An-Havva"		, { 1    , 2     } },
	["Bewohner von An-Havva (1)"] 	= { "Bewohner von An-Havva"		, { 1    , false } },
	["Bewohner von An-Havva (2)"] 	= { "Bewohner von An-Havva"		, { false, 2     } },
["Giant Albatross"] 				= { "Giant Albatross"			, { 1    , 2     } },
["Giant Albatross (1)"] 			= { "Giant Albatross"			, { 1    , false } },
["Giant Albatross (2)"] 			= { "Giant Albatross"			, { false, 2     } },
	["Riesenalbatros"] 				= { "Riesenalbatros"			, { 1    , 2     } },
	["Riesenalbatros (1)"] 			= { "Riesenalbatros"			, { 1    , false } },
	["Riesenalbatros (2)"] 			= { "Riesenalbatros"			, { false, 2     } },
["Hungry Mist"] 					= { "Hungry Mist"				, { 1    , 2     } },
["Hungry Mist (1)"] 				= { "Hungry Mist"				, { 1    , false } },
["Hungry Mist (2)"] 				= { "Hungry Mist"				, { false, 2     } },
	["Hungrige Nebelschwaden"]	 	= { "Hungrige Nebelschwaden"	, { 1    , 2     } },
	["Hungrige Nebelschwaden (1)"]	= { "Hungrige Nebelschwaden"	, { 1    , false } },
	["Hungrige Nebelschwaden (2)"]	= { "Hungrige Nebelschwaden"	, { false, 2     } },
["Labyrinth Minotaur"] 				= { "Labyrinth Minotaur"		, { 1    , 2     } },
["Labyrinth Minotaur (1)"] 			= { "Labyrinth Minotaur"		, { 1    , false } },
["Labyrinth Minotaur (2)"] 			= { "Labyrinth Minotaur"		, { false, 2     } },
	["Labyrinthminotaurus"] 		= { "Labyrinthminotaurus"		, { 1    , 2     } },
	["Labyrinthminotaurus (1)"] 	= { "Labyrinthminotaurus"		, { 1    , false } },
	["Labyrinthminotaurus (2)"] 	= { "Labyrinthminotaurus"		, { false, 2     } },
["Memory Lapse"] 					= { "Memory Lapse"				, { 1    , 2     } },
["Memory Lapse (1)"]	 			= { "Memory Lapse"				, { 1    , false } },
["Memory Lapse (2)"] 				= { "Memory Lapse"				, { false, 2     } },
	["Gedächtnislücke"] 			= { "Gedächtnislücke"			, { 1    , 2     } },
	["Gedächnislücke (1)"] 			= { "Gedächnislücke"			, { 1    , false } },
	["Gedächnislücke (2)"]	 		= { "Gedächnislücke"			, { false, 2     } },
["Mesa Falcon"] 					= { "Mesa Falcon"				, { 1    , 2     } },
["Mesa Falcon (1)"] 				= { "Mesa Falcon"				, { 1    , false } },
["Mesa Falcon (2)"]	 				= { "Mesa Falcon"				, { false, 2     } },
	["Mesafalken"] 					= { "Mesafalken"				, { 1    , 2     } },
	["Mesafalken (1)"] 				= { "Mesafalken"				, { 1    , false } },
	["Mesafalken (2)"] 				= { "Mesafalken"				, { false, 2     } },
["Reef Pirates"] 					= { "Reef Pirates"				, { 1    , 2     } },
["Reef Pirates (1)"] 				= { "Reef Pirates"				, { 1    , false } },
["Reef Pirates (2)"] 				= { "Reef Pirates"				, { false, 2     } },
	["Riffpiraten"] 				= { "Riffpiraten"				, { 1    , 2     } },
	["Riffpiraten (1)"] 			= { "Riffpiraten"				, { 1    , false } },
	["Riffpiraten (2)"] 			= { "Riffpiraten"				, { false, 2     } },
["Samite Alchemist"] 				= { "Samite Alchemist"			, { 1    , 2     } },
["Samite Alchemist (1)"] 			= { "Samite Alchemist"			, { 1    , false } },
["Samite Alchemist (2)"] 			= { "Samite Alchemist"			, { false, 2     } },
	["Samitischer Alchimist"]	 	= { "Samitischer Alchimist"		, { 1    , 2     } },
	["Samitischer Alchimist (1)"] 	= { "Samitischer Alchimist"		, { 1    , false } },
	["Samitischer Alchimist (2)"] 	= { "Samitischer Alchimist"		, { false, 2     } },
["Shrink"] 							= { "Shrink"					, { 1    , 2     } },
["Shrink (1)"]	 					= { "Shrink"					, { 1    , false } },
["Shrink (2)"] 						= { "Shrink"					, { false, 2     } },
	["Schrumpfen"] 					= { "Schrumpfen"				, { 1    , 2     } },
	["Schrumpfen (1)"] 				= { "Schrumpfen"				, { 1    , false } },
	["Schrumpfen (2)"] 				= { "Schrumpfen"				, { false, 2     } },
["Sengir Bats"] 					= { "Sengir Bats"				, { 1    , 2     } },
["Sengir Bats (1)"] 				= { "Sengir Bats"				, { 1    , false } },
["Sengir Bats (2)"] 				= { "Sengir Bats"				, { false, 2     } },
	["Sengirs Fledermäuse"] 		= { "Sengirs Fledermäuse"		, { 1    , 2     } },
	["Sengirs Fledermäuse (1)"] 	= { "Sengirs Fledermäuse"		, { 1    , false } },
	["Sengirs Fledermäuse (2)"] 	= { "Sengirs Fledermäuse"		, { false, 2     } },
["Torture"] 						= { "Torture"					, { 1    , 2     } },
["Torture (1)"] 					= { "Torture"					, { 1    , false } },
["Torture (2)"] 					= { "Torture"					, { false, 2     } },
	["Folterung"] 					= { "Folterung"					, { 1    , 2     } },
	["Folterung (1)"]	 			= { "Folterung"					, { 1    , false } },
	["Folterung (2)"] 				= { "Folterung"					, { false, 2     } },
["Trade Caravan"] 					= { "Trade Caravan"				, { 1    , 2     } },
["Trade Caravan (1)"]	 			= { "Trade Caravan"				, { 1    , false } },
["Trade Caravan (2)"] 				= { "Trade Caravan"				, { false, 2     } },
	["Handelskarawane"] 			= { "Handelskarawane"			, { 1    , 2     } },
	["Handelskarawane (1)"] 		= { "Handelskarawane"			, { 1    , false } },
	["Handelskarawane (2)"] 		= { "Handelskarawane"			, { false, 2     } },
["Willow Faerie"]	 				= { "Willow Faerie"				, { 1    , 2     } },
["Willow Faerie (1)"] 				= { "Willow Faerie"				, { 1    , false } },
["Willow Faerie (2)"] 				= { "Willow Faerie"				, { false, 2     } },
	["Weidenfee"] 					= { "Weidenfee"					, { 1    , 2     } },
	["Weidenfee (1)"]		 		= { "Weidenfee"					, { 1    , false } },
	["Weidenfee (2)"] 				= { "Weidenfee"					, { false, 2     } },
	},
},
[190] = { name="Ice Age",
	cardcount={ reg = 383, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false } },
["Plains (2)"]					= { "Plains"	, { false, 2    , false } },
["Plains (3)"]					= { "Plains"	, { false, false, 3     } },
["Island (1)"]					= { "Island"	, { 1    , false, false } },
["Island (2)"]					= { "Island"	, { false, 2    , false } },
["Island (3)"]					= { "Island"	, { false, false, 3     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (3)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (3)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (1)"]					= { "Forest"	, { 1    , false, false } },
["Forest (2)"]					= { "Forest"	, { false, 2    , false } },
["Forest (3)"]					= { "Forest"	, { false, false, 3     } },
	},
},
[170] = { name="Fallen Empires",
	cardcount={ reg = 187, tok =  0 },
	variants={
["Armor Thrull"]	 				= { "Armor Thrull"					, { 1    , 2    , 3    , 4     } },
["Armor Thrull (1)"]	 			= { "Armor Thrull"					, { 1    , false, false, false } },
["Armor Thrull (2)"] 				= { "Armor Thrull"					, { false, 2    , false, false } },
["Armor Thrull (3)"] 				= { "Armor Thrull"					, { false, false, 3    , false } },
["Armor Thrull (4)"] 				= { "Armor Thrull"					, { false, false, false, 4     } },
["Basal Thrull"] 					= { "Basal Thrull"					, { 1    , 2    , 3    , 4     } },
["Basal Thrull (1)"]	 			= { "Basal Thrull"					, { 1    , false, false, false } },
["Basal Thrull (2)"] 				= { "Basal Thrull"					, { false, 2    , false, false } },
["Basal Thrull (3)"] 				= { "Basal Thrull"					, { false, false, 3    , false } },
["Basal Thrull (4)"] 				= { "Basal Thrull"					, { false, false, false, 4     } },
["Brassclaw Orcs"] 					= { "Brassclaw Orcs"				, { 1    , 2    , 3    , 4     } },
["Brassclaw Orcs (1)"]	 			= { "Brassclaw Orcs"				, { 1    , false, false, false } },
["Brassclaw Orcs (2)"] 				= { "Brassclaw Orcs"				, { false, 2    , false, false } },
["Brassclaw Orcs (3)"] 				= { "Brassclaw Orcs"				, { false, false, 3    , false } },
["Brassclaw Orcs (4)"] 				= { "Brassclaw Orcs"				, { false, false, false, 4     } },
["Combat Medic"] 					= { "Combat Medic"					, { 1    , 2    , 3    , 4     } },
["Combat Medic (1)"] 				= { "Combat Medic"					, { 1    , false, false, false } },
["Combat Medic (2)"] 				= { "Combat Medic"					, { false, 2    , false, false } },
["Combat Medic (3)"] 				= { "Combat Medic"					, { false, false, 3    , false } },
["Combat Medic (4)"] 				= { "Combat Medic"					, { false, false, false, 4     } },
["Dwarven Soldier"] 				= { "Dwarven Soldier"				, { 1    , 2    , 3     } },
["Dwarven Soldier (1)"]				= { "Dwarven Soldier"				, { 1    , false, false } },
["Dwarven Soldier (2)"]				= { "Dwarven Soldier"				, { false, 2    , false } },
["Dwarven Soldier (3)"]				= { "Dwarven Soldier"				, { false, false, 3     } },
["Elven Fortress"] 					= { "Elven Fortress"				, { 1    , 2    , 3    , 4     } },
["Elven Fortress (1)"] 				= { "Elven Fortress"				, { 1    , false, false, false } },
["Elven Fortress (2)"] 				= { "Elven Fortress"				, { false, 2    , false, false } },
["Elven Fortress (3)"] 				= { "Elven Fortress"				, { false, false, 3    , false } },
["Elven Fortress (4)"] 				= { "Elven Fortress"				, { false, false, false, 4     } },
["Elvish Hunter"] 					= { "Elvish Hunter"					, { 1    , 2    , 3     } },
["Elvish Hunter (1)"]				= { "Elvish Hunter"					, { 1    , false, false } },
["Elvish Hunter (2)"]				= { "Elvish Hunter"					, { false, 2    , false } },
["Elvish Hunter (3)"]				= { "Elvish Hunter"					, { false, false, 3     } },
["Elvish Scout"] 					= { "Elvish Scout"					, { 1    , 2    , 3     } },
["Elvish Scout (1)"]				= { "Elvish Scout"					, { 1    , false, false } },
["Elvish Scout (2)"]				= { "Elvish Scout"					, { false, 2    , false } },
["Elvish Scout (3)"]				= { "Elvish Scout"					, { false, false, 3     } },
["Farrel's Zealot"] 				= { "Farrel's Zealot"				, { 1    , 2    , 3     } },
["Farrel's Zealot (1)"]				= { "Farrel's Zealot"				, { 1    , false, false } },
["Farrel's Zealot (2)"]				= { "Farrel's Zealot"				, { false, 2    , false } },
["Farrel's Zealot (3)"]				= { "Farrel's Zealot"				, { false, false, 3     } },
["Goblin Chirurgeon"] 				= { "Goblin Chirurgeon"				, { 1    , 2    , 3     } },
["Goblin Chirurgeon (1)"]			= { "Goblin Chirurgeon"				, { 1    , false, false } },
["Goblin Chirurgeon (2)"]			= { "Goblin Chirurgeon"				, { false, 2    , false } },
["Goblin Chirurgeon (3)"]			= { "Goblin Chirurgeon"				, { false, false, 3     } },
["Goblin Grenade"] 					= { "Goblin Grenade"				, { 1    , 2    , 3     } },
["Goblin Grenade (1)"]				= { "Goblin Grenade"				, { 1    , false, false } },
["Goblin Grenade (2)"]				= { "Goblin Grenade"				, { false, 2    , false } },
["Goblin Grenade (3)"]				= { "Goblin Grenade"				, { false, false, 3     } },
["Goblin War Drums"] 				= { "Goblin War Drums"				, { 1    , 2    , 3    , 4     } },
["Goblin War Drums (1)"]	 		= { "Goblin War Drums"				, { 1    , false, false, false } },
["Goblin War Drums (2)"] 			= { "Goblin War Drums"				, { false, 2    , false, false } },
["Goblin War Drums (3)"] 			= { "Goblin War Drums"				, { false, false, 3    , false } },
["Goblin War Drums (4)"]	 		= { "Goblin War Drums"				, { false, false, false, 4     } },
["High Tide"] 						= { "High Tide"						, { 1    , 2    , 3     } },
["High Tide (1)"]					= { "High Tide"						, { 1    , false, false } },
["High Tide (2)"]					= { "High Tide"						, { false, 2    , false } },
["High Tide (3)"]					= { "High Tide"						, { false, false, 3     } },
["Homarid"] 						= { "Homarid"						, { 1    , 2    , 3    , 4     } },
["Homarid (1)"] 					= { "Homarid"						, { 1    , false, false, false } },
["Homarid (2)"] 					= { "Homarid"						, { false, 2    , false, false } },
["Homarid (3)"] 					= { "Homarid"						, { false, false, 3    , false } },
["Homarid (4)"] 					= { "Homarid"						, { false, false, false, 4     } },
["Homarid Warrior"] 				= { "Homarid Warrior"				, { 1    , 2    , 3     } },
["Homarid Warrior (1)"]				= { "Homarid Warrior"				, { 1    , false, false } },
["Homarid Warrior (2)"]				= { "Homarid Warrior"				, { false, 2    , false } },
["Homarid Warrior (3)"]				= { "Homarid Warrior"				, { false, false, 3     } },
["Hymn to Tourach"] 				= { "Hymn to Tourach"				, { 1    , 2    , 3    , 4     } },
["Hymn to Tourach (1)"] 			= { "Hymn to Tourach"				, { 1    , false, false, false } },
["Hymn to Tourach (2)"] 			= { "Hymn to Tourach"				, { false, 2    , false, false } },
["Hymn to Tourach (3)"] 			= { "Hymn to Tourach"				, { false, false, 3    , false } },
["Hymn to Tourach (4)"] 			= { "Hymn to Tourach"				, { false, false, false, 4     } },
["Icatian Infantry"] 				= { "Icatian Infantry"				, { 1    , 2    , 3    , 4     } },
["Icatian Infantry (1)"] 			= { "Icatian Infantry"				, { 1    , false, false, false } },
["Icatian Infantry (2)"] 			= { "Icatian Infantry"				, { false, 2    , false, false } },
["Icatian Infantry (3)"]	 		= { "Icatian Infantry"				, { false, false, 3    , false } },
["Icatian Infantry (4)"] 			= { "Icatian Infantry"				, { false, false, false, 4     } },
["Icatian Javelineers"] 			= { "Icatian Javelineers"			, { 1    , 2    , 3     } },
["Icatian Javelineers (1)"]			= { "Icatian Javelineers"			, { 1    , false, false } },
["Icatian Javelineers (2)"]			= { "Icatian Javelineers"			, { false, 2    , false } },
["Icatian Javelineers (3)"]			= { "Icatian Javelineers"			, { false, false, 3     } },
["Icatian Moneychanger"] 			= { "Icatian Moneychanger"			, { 1    , 2    , 3     } },
["Icatian Moneychanger (1)"]		= { "Icatian Moneychanger"			, { 1    , false, false } },
["Icatian Moneychanger (2)"]		= { "Icatian Moneychanger"			, { false, 2    , false } },
["Icatian Moneychanger (3)"]		= { "Icatian Moneychanger"			, { false, false, 3     } },
["Icatian Scout"] 					= { "Icatian Scout"					, { 1    , 2    , 3    , 4     } },
["Icatian Scout (1)"] 				= { "Icatian Scout"					, { 1    , false, false, false } },
["Icatian Scout (2)"] 				= { "Icatian Scout"					, { false, 2    , false, false } },
["Icatian Scout (3)"] 				= { "Icatian Scout"					, { false, false, 3    , false } },
["Icatian Scout (4)"] 				= { "Icatian Scout"					, { false, false, false, 4     } },
["Initiates of the Ebon Hand"]	 	= { "Initiates of the Ebon Hand"	, { 1    , 2    , 3     } },
["Initiates of the Ebon Hand (1)"]	= { "Initiates of the Ebon Hand"	, { 1    , false, false } },
["Initiates of the Ebon Hand (2)"]	= { "Initiates of the Ebon Hand"	, { false, 2    , false } },
["Initiates of the Ebon Hand (3)"]	= { "Initiates of the Ebon Hand"	, { false, false, 3     } },
["Merseine"] 						= { "Merseine"						, { 1    , 2    , 3    , 4     } },
["Merseine (1)"] 					= { "Merseine"						, { 1    , false, false, false } },
["Merseine (2)"] 					= { "Merseine"						, { false, 2    , false, false } },
["Merseine (3)"] 					= { "Merseine"						, { false, false, 3    , false } },
["Merseine (4)"]	 				= { "Merseine"						, { false, false, false, 4     } },
["Mindstab Thrull"]	 				= { "Mindstab Thrull"				, { 1    , 2    , 3     } },
["Mindstab Thrull (1)"]				= { "Mindstab Thrull"				, { 1    , false, false } },
["Mindstab Thrull (2)"]				= { "Mindstab Thrull"				, { false, 2    , false } },
["Mindstab Thrull (3)"]				= { "Mindstab Thrull"				, { false, false, 3     } },
["Necrite"] 						= { "Necrite"						, { 1    , 2    , 3     } },
["Necrite (1)"]						= { "Necrite"						, { 1    , false, false } },
["Necrite (2)"]						= { "Necrite"						, { false, 2    , false } },
["Necrite (3)"]						= { "Necrite"						, { false, false, 3     } },
["Night Soil"] 						= { "Night Soil"					, { 1    , 2    , 3     } },
["Night Soil (1)"]					= { "Night Soil"					, { 1    , false, false } },
["Night Soil (2)"]					= { "Night Soil"					, { false, 2    , false } },
["Night Soil (3)"]					= { "Night Soil"					, { false, false, 3     } },
["Orcish Spy"] 						= { "Orcish Spy"					, { 1    , 2    , 3     } },
["Orcish Spy (1)"]					= { "Orcish Spy"					, { 1    , false, false } },
["Orcish Spy (2)"]					= { "Orcish Spy"					, { false, 2    , false } },
["Orcish Spy (3)"]					= { "Orcish Spy"					, { false, false, 3     } },
["Orcish Veteran"] 					= { "Orcish Veteran"				, { 1    , 2    , 3    , 4     } },
["Orcish Veteran (1)"] 				= { "Orcish Veteran"				, { 1    , false, false, false } },
["Orcish Veteran (2)"] 				= { "Orcish Veteran"				, { false, 2    , false, false } },
["Orcish Veteran (3)"] 				= { "Orcish Veteran"				, { false, false, 3    , false } },
["Orcish Veteran (4)"]	 			= { "Orcish Veteran"				, { false, false, false, 4     } },
["Order of the Ebon Hand"]	 		= { "Order of the Ebon Hand"		, { 1    , 2    , 3     } },
["Order of the Ebon Hand (1)"]		= { "Order of the Ebon Hand"		, { 1    , false, false } },
["Order of the Ebon Hand (2)"]		= { "Order of the Ebon Hand"		, { false, 2    , false } },
["Order of the Ebon Hand (3)"]		= { "Order of the Ebon Hand"		, { false, false, 3     } },
["Order of Leitbur"]	 			= { "Order of Leitbur"				, { 1    , 2    , 3     } },
["Order of Leitbur (1)"]			= { "Order of Leitbur"				, { 1    , false, false } },
["Order of Leitbur (2)"]			= { "Order of Leitbur"				, { false, 2    , false } },
["Order of Leitbur (3)"]			= { "Order of Leitbur"				, { false, false, 3     } },
["Spore Cloud"] 					= { "Spore Cloud"					, { 1    , 2    , 3     } },
["Spore Cloud (1)"]					= { "Spore Cloud"					, { 1    , false, false } },
["Spore Cloud (2)"]					= { "Spore Cloud"					, { false, 2    , false } },
["Spore Cloud (3)"]					= { "Spore Cloud"					, { false, false, 3     } },
["Thallid"] 						= { "Thallid"						, { 1    , 2    , 3    , 4     } },
["Thallid (1)"] 					= { "Thallid"						, { 1    , false, false, false } },
["Thallid (2)"] 					= { "Thallid"						, { false, 2    , false, false } },
["Thallid (3)"] 					= { "Thallid"						, { false, false, 3    , false } },
["Thallid (4)"] 					= { "Thallid"						, { false, false, false, 4     } },
["Thorn Thallid"] 					= { "Thorn Thallid"					, { 1    , 2    , 3    , 4     } },
["Thorn Thallid (1)"] 				= { "Thorn Thallid"					, { 1    , false, false, false } },
["Thorn Thallid (2)"] 				= { "Thorn Thallid"					, { false, 2    , false, false } },
["Thorn Thallid (3)"] 				= { "Thorn Thallid"					, { false, false, 3    , false } },
["Thorn Thallid (4)"] 				= { "Thorn Thallid"					, { false, false, false, 4     } },
["Tidal Flats"] 					= { "Tidal Flats"					, { 1    , 2    , 3     } },
["Tidal Flats (1)"]					= { "Tidal Flats"					, { 1    , false, false } },
["Tidal Flats (2)"]					= { "Tidal Flats"					, { false, 2    , false } },
["Tidal Flats (3)"]					= { "Tidal Flats"					, { false, false, 3     } },
["Vodalian Soldiers"] 				= { "Vodalian Soldiers"				, { 1    , 2    , 3    , 4     } },
["Vodalian Soldiers (1)"] 			= { "Vodalian Soldiers"				, { 1    , false, false, false } },
["Vodalian Soldiers (2)"] 			= { "Vodalian Soldiers"				, { false, 2    , false, false } },
["Vodalian Soldiers (3)"] 			= { "Vodalian Soldiers"				, { false, false, 3    , false } },
["Vodalian Soldiers (4)"] 			= { "Vodalian Soldiers"				, { false, false, false, 4     } },
["Vodalian Mage"] 					= { "Vodalian Mage"					, { 1    , 2    , 3     } },
["Vodalian Mage (1)"]				= { "Vodalian Mage"					, { 1    , false, false } },
["Vodalian Mage (2)"]				= { "Vodalian Mage"					, { false, 2    , false } },
["Vodalian Mage (3)"]				= { "Vodalian Mage"					, { false, false, 3     } },
	},
},
[160] = { name="The Dark",
	cardcount={ reg = 119, tok =  0 },
	variants={}
},
[150] = { name="Legends",
	cardcount={ reg = 310, tok =  0 },
	variants={}
},
[130] = { name="Antiquities",
	cardcount={ reg = 100, tok =  0 },
	variants={
["Mishra's Factory"] 			= { "Mishra's Factory"	, { 1    , 2    , 3    , 4     } },
["Mishra's Factory (Spring)"] 	= { "Mishra's Factory"	, { 1    , false, false, false } },
["Mishra's Factory (Summer)"] 	= { "Mishra's Factory"	, { false, 2    , false, false } },
["Mishra's Factory (Autumn)"] 	= { "Mishra's Factory"	, { false, false, 3    , false } },
["Mishra's Factory (Winter)"] 	= { "Mishra's Factory"	, { false, false, false, 4     } },
["Mishra's Factory (1)"]	 	= { "Mishra's Factory"	, { 1    , false, false, false } },
["Mishra's Factory (2)"]	 	= { "Mishra's Factory"	, { false, 2    , false, false } },
["Mishra's Factory (3)"] 		= { "Mishra's Factory"	, { false, false, 3    , false } },
["Mishra's Factory (4)"] 		= { "Mishra's Factory"	, { false, false, false, 4     } },
["Strip Mine"] 					= { "Strip Mine"		, { 1    , 2    , 3    , 4     } },
["Strip Mine (1)"] 				= { "Strip Mine"		, { 1    , false, false, false } },--No Horizon
["Strip Mine (2)"] 				= { "Strip Mine"		, { false, 2    , false, false } },--Uneven Horizon
["Strip Mine (3)"] 				= { "Strip Mine"		, { false, false, 3    , false } },--Tower
["Strip Mine (4)"] 				= { "Strip Mine"		, { false, false, false, 4     } },--Even Horizon
["Urza's Mine"] 				= { "Urza's Mine"		, { 1    , 2    , 3    , 4     } },
["Urza's Mine (1)"]	 			= { "Urza's Mine"		, { 1    , false, false, false } },--Pully
["Urza's Mine (2)"] 			= { "Urza's Mine"		, { false, 2    , false, false } },--Mouth
["Urza's Mine (3)"] 			= { "Urza's Mine"		, { false, false, 3    , false } },--Clawed Sphere
["Urza's Mine (4)"] 			= { "Urza's Mine"		, { false, false, false, 4     } },--Tower
["Urza's Power Plant"] 			= { "Urza's Power Plant", { 1    , 2    , 3    , 4     } },
["Urza's Power Plant (1)"]	 	= { "Urza's Power Plant", { 1    , false, false, false } },--Sphere
["Urza's Power Plant (2)"] 		= { "Urza's Power Plant", { false, 2    , false, false } },--Columns
["Urza's Power Plant (3)"] 		= { "Urza's Power Plant", { false, false, 3    , false } },--Bug
["Urza's Power Plant (4)"] 		= { "Urza's Power Plant", { false, false, false, 4     } },--Rock in Pot
["Urza's Tower"] 				= { "Urza's Tower"		, { 1    , 2    , 3    , 4     } },
["Urza's Tower (1)"] 			= { "Urza's Tower"		, { 1    , false, false, false } },--Forest
["Urza's Tower (2)"] 			= { "Urza's Tower"		, { false, 2    , false, false } },--Shore
["Urza's Tower (3)"] 			= { "Urza's Tower"		, { false, false, 3    , false } },--Plains
["Urza's Tower (4)"] 			= { "Urza's Tower"		, { false, false, false, 4     } },--Mountains
	},
},
[120] = { name="Arabian Nights",
	cardcount={ reg = 92 , tok =  0 },
	variants={
["Army of Allah"] 				= { "Army of Allah"			, { 1    , 2     } },
["Army of Allah (1)"] 			= { "Army of Allah"			, { 1    , false } },
["Army of Allah (2)"] 			= { "Army of Allah"			, { false, 2     } },
["Bird Maiden"] 				= { "Bird Maiden"			, { 1    , 2     } },
["Bird Maiden (1)"] 			= { "Bird Maiden"			, { 1    , false } },
["Bird Maiden (2)"] 			= { "Bird Maiden"			, { false, 2     } },
["Erg Raiders"] 				= { "Erg Raiders"			, { 1    , 2     } },
["Erg Raiders (1)"] 			= { "Erg Raiders"			, { 1    , false } },
["Erg Raiders (2)"] 			= { "Erg Raiders"			, { false, 2     } },
["Fishliver Oil"] 				= { "Fishliver Oil"			, { 1    , 2     } },
["Fishliver Oil (1)"] 			= { "Fishliver Oil"			, { 1    , false } },
["Fishliver Oil (2)"] 			= { "Fishliver Oil"			, { false, 2     } },
["Giant Tortoise"] 				= { "Giant Tortoise"		, { 1    , 2     } },
["Giant Tortoise (1)"] 			= { "Giant Tortoise"		, { 1    , false } },
["Giant Tortoise (2)"]			= { "Giant Tortoise"		, { false, 2     } },
["Hasran Ogress"] 				= { "Hasran Ogress"			, { 1    , 2     } },
["Hasran Ogress (1)"] 			= { "Hasran Ogress"			, { 1    , false } },
["Hasran Ogress (2)"] 			= { "Hasran Ogress"			, { false, 2     } },
["Moorish Cavalry"] 			= { "Moorish Cavalry"		, { 1    , 2     } },
["Moorish Cavalry (1)"] 		= { "Moorish Cavalry"		, { 1    , false } },
["Moorish Cavalry (2)"]			= { "Moorish Cavalry"		, { false, 2     } },
["Nafs Asp"] 					= { "Nafs Asp"				, { 1    , 2     } },
["Nafs Asp (1)"] 				= { "Nafs Asp"				, { 1    , false } },
["Nafs Asp (2)"] 				= { "Nafs Asp"				, { false, 2     } },
["Oubliette"] 					= { "Oubliette"				, { 1    , 2     } },
["Oubliette (1)"] 				= { "Oubliette"				, { 1    , false } },
["Oubliette (2)"] 				= { "Oubliette"				, { false, 2     } },
["Rukh Egg"] 					= { "Rukh Egg"				, { 1    , 2     } },
["Rukh Egg (1)"] 				= { "Rukh Egg"				, { 1    , false } },
["Rukh Egg (2)"] 				= { "Rukh Egg"				, { false, 2     } },
["Piety"] 						= { "Piety"					, { 1    , 2     } },
["Piety (1)"] 					= { "Piety"					, { 1    , false } },
["Piety (2)"] 					= { "Piety"					, { false, 2     } },
["Stone-Throwing Devils"] 		= { "Stone-Throwing Devils"	, { 1    , 2     } },
["Stone-Throwing Devils (1)"] 	= { "Stone-Throwing Devils"	, { 1    , false } },
["Stone-Throwing Devils (2)"] 	= { "Stone-Throwing Devils"	, { false, 2     } },
["War Elephant"] 				= { "War Elephant"			, { 1    , 2     } },
["War Elephant (1)"] 			= { "War Elephant"			, { 1    , false } },
["War Elephant (2)"]		 	= { "War Elephant"			, { false, 2     } },
["Wyluli Wolf"] 				= { "Wyluli Wolf"			, { 1    , 2     } },
["Wyluli Wolf (1)"] 			= { "Wyluli Wolf"			, { 1    , false } },
["Wyluli Wolf (2)"] 			= { "Wyluli Wolf"			, { false, 2     } },
	},
},
--- not really a seperate subtable, just a bookmark for quick navigation in eclipse.
-- @field [parent=#Data.sets] #table SpecialSets
SpecialSets = nil,
[807] = { name="Conspiracy",
--TODO [807] tokens
	foil="y",
	cardcount={ reg=197, tok=0, nontr=13, overs=0 },
},
[805] = { name="Duel Decks: Jace vs. Vraska",
	foil="n",
	cardcount={ reg=88, tok=1, nontr=0, overs=0 },
	variants={
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4    , 5     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4    , 5     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4    , 5     } },
["Island (37)"]					= { "Island"	, { 1    , false, false, false, false } },
["Island (38)"]					= { "Island"	, { false, 2    , false, false, false } },
["Island (39)"]					= { "Island"	, { false, false, 3    , false, false } },
["Island (40)"]					= { "Island"	, { false, false, false, 4    , false } },
["Island (41)"]					= { "Island"	, { false, false, false, false, 5     } },
["Swamp (79)"]					= { "Swamp" 	, { 1    , false, false, false, false } },
["Swamp (80)"]					= { "Swamp" 	, { false, 2    , false, false, false } },
["Swamp (81)"]					= { "Swamp" 	, { false, false, 3    , false, false } },
["Swamp (82)"]					= { "Swamp" 	, { false, false, false, 4    , false } },
["Swamp (83)"]					= { "Swamp" 	, { false, false, false, false, 5     } },
["Forest (84)"]					= { "Forest"	, { 1    , false, false, false, false } },
["Forest (85)"]					= { "Forest"	, { false, 2    , false, false, false } },
["Forest (86)"]					= { "Forest"	, { false, false, 3    , false, false } },
["Forest (87)"]					= { "Forest"	, { false, false, false, 4    , false } },
["Forest (88)"]					= { "Forest"	, { false, false, false, false, 5     } }
	},
	foiltweak={
["Jace, Architect of Thought"]	= { foil = true},
["Vraska the Unseen"]			= { foil = true},
	},
},
[804] = { name="Challenge Deck: Battle the Horde",
	foil="n",
	cardcount={ reg=0, tok=0, nontr=15, overs=0 },
},
[803] = { name="Challenge Deck: Face the Hydra",
	foil="n",
	cardcount={ reg=0, tok=0, nontr=15, overs=0 },
},
[801] = { name="Commander 2013 Edition",
	foil="n",--15 oversized are foilonly
	cardcount={ reg=356, tok=0, nontr=0, overs=15 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (337)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (338)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (339)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (340)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (341)"]				= { "Island"	, { 1    , false, false, false } },
["Island (342)"]				= { "Island"	, { false, 2    , false, false } },
["Island (343)"]				= { "Island"	, { false, false, 3    , false } },
["Island (344)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (345)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (346)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (347)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (348)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (349)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (350)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (351)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (352)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (353)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (354)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (355)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (356)"]				= { "Forest"	, { false, false, false, 4     } },
	},
--TODO [801] how to set regular vs oversized ?!? also, make foiltweak table for (oversized)
},
[799] = { name="Duel Decks: Heroes vs. Monsters",
	foil="n",
	cardcount={ reg=81, tok=2, nontr=0, overs=0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     , 5    , 6    , 7    , 8    } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Mountain (35)"]				= { "Mountain"	, { 1    , false, false, false, false, false, false, false } },
["Mountain (36)"]				= { "Mountain"	, { false, 2    , false, false, false, false, false, false } },
["Mountain (37)"]				= { "Mountain"	, { false, false, 3    , false, false, false, false, false } },
["Mountain (38)"]				= { "Mountain"	, { false, false, false, 4    , false, false, false, false } },
["Plains (39)"]					= { "Plains"	, { 1    , false, false, false } }, 
["Plains (40)"]					= { "Plains"	, { false, 2    , false, false } },
["Plains (41)"]					= { "Plains"	, { false, false, 3    , false } },
["Plains (42)"]					= { "Plains"	, { false, false, false, 4     } },
["Mountain (74)"]				= { "Mountain"	, { false, false, false, false, 5    , false, false, false } },
["Mountain (75)"]				= { "Mountain"	, { false, false, false, false, false, 6    , false, false } },
["Mountain (76)"]				= { "Mountain"	, { false, false, false, false, false, false, 7    , false } },
["Mountain (77)"]				= { "Mountain"	, { false, false, false, false, false, false, false, 8     } },
["Forest (78)"]					= { "Forest"	, { 1    , false, false, false } },
["Forest (79)"]					= { "Forest"	, { false, 2    , false, false } },
["Forest (80)"]					= { "Forest"	, { false, false, 3    , false } },
["Forest (81)"]					= { "Forest"	, { false, false, false, 4     } },
	},
	foiltweak={
["Sun Titan"]					= { foil = false},
["Polukranos, World Eater"]		= { foil = false},
	},
},
[798] = { name="From the Vault: Twenty",
	foilonly=true,
	cardcount={ reg=20, tok=0, nontr=0, overs=0 }, 
},
[796] = { name="Modern Masters",
	cardcount={ reg = 229, tok = 16 },
},
[794] = { name="Duel Decks: Sorin vs. Tibalt",
	foil="n",
	cardcount={ reg=80, tok=1, nontr=0, overs=0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3 } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4    , 5    , 6     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3 } },
["Plains (38)"]					= { "Plains"	, { 1    , false, false } },
["Plains (39)"]					= { "Plains"	, { false, 2    , false } },
["Plains (40)"]					= { "Plains"	, { false, false, 3     } },
["Swamp (35)"]					= { "Swamp"		, { 1    , false, false, false, false, false } },
["Swamp (36)"] 					= { "Swamp"		, { false, 2    , false, false, false, false } },
["Swamp (37)"] 					= { "Swamp"		, { false, false, 3    , false, false, false } },
["Swamp (78)"] 					= { "Swamp"		, { false, false, false, 4    , false, false } },
["Swamp (79)"] 					= { "Swamp"		, { false, false, false, false, 5    , false } },
["Swamp (80)"] 					= { "Swamp"		, { false, false, false, false, false, 6     } },
["Mountain (75)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (76)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (77)"]				= { "Mountain"	, { false, false, 3     } },
	},
	foiltweak={
["Sorin, Lord of Innistrad"]		= { foil = true},
["Tibalt, the Fiend-Blooded"]		= { foil = true},
	},
},
[792] = { name="Commander’s Arsenal",
	foilonly=true,
	cardcount={ reg=18, tok=0, nontr=0, overs=10 }, 
},
[790] = { name="Duel Decks: Izzet vs. Golgari",
	foil="n",
	cardcount={ reg=90, tok=1, nontr=0, overs=0 }, 
	variants={
["Island"] 						= { "Island"	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest"	, { 1    , 2    , 3    , 4     } },
["Island (37)"]					= { "Island"	, { 1    , false, false, false } }, 
["Island (38)"]					= { "Island"	, { false, 2    , false, false } },
["Island (39)"]					= { "Island"	, { false, false, 3    , false } },
["Island (40)"]					= { "Island"	, { false, false, false, 4     } },
["Swamp (83)"]					= { "Swamp"		, { 1    , false, false, false } }, 
["Swamp (84)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (85)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (86)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (41)"]				= { "Mountain"	, { 1    , false, false, false } }, 
["Mountain (42)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (43)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (44)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (87)"]					= { "Forest"	, { 1    , false, false, false } }, 
["Forest (88)"]					= { "Forest"	, { false, 2    , false, false } },
["Forest (89)"]					= { "Forest"	, { false, false, 3    , false } },
["Forest (90)"]					= { "Forest"	, { false, false, false, 4     } },
	},
	foiltweak={
["Niv-Mizzet, the Firemind"]		= { foil = true},
["Jarad, Golgari Lich Lord"]		= { foil = true},
	},
},
[789] = { name="From the Vault: Realms",
	foilonly=true,
	cardcount={ reg=15, tok=0, nontr=0, overs=0 }, 
},
[787] = { name="Planechase 2012",
	foil="n",
	cardcount={ reg=156, tok=0, nontr=40, overs=0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4    , 5     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4    , 5     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4    , 5     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4    , 5    , 6     } },
["Plains (132)"]				= { "Plains"	, { 1    , false, false, false, false } },
["Plains (133)"]				= { "Plains"	, { false, 2    , false, false, false } },
["Plains (134)"]				= { "Plains"	, { false, false, 3    , false, false } },
["Plains (135)"]				= { "Plains"	, { false, false, false, 4    , false } },
["Plains (136)"]				= { "Plains"	, { false, false, false, false, 5     } },
["Island (137)"]				= { "Island"	, { 1    , false, false, false, false } },
["Island (138)"]				= { "Island"	, { false, 2    , false, false, false } },
["Island (139)"] 				= { "Island"	, { false, false, 3    , false, false } },
["Island (140)"]				= { "Island"	, { false, false, false, 4    , false } },
["Island (141)"]				= { "Island"	, { false, false, false, false, 5     } },
["Swamp (142)"]					= { "Swamp" 	, { 1    , false, false, false, false } },
["Swamp (143)"]					= { "Swamp" 	, { false, 2    , false, false, false } },
["Swamp (144)"]					= { "Swamp" 	, { false, false, 3    , false, false } },
["Swamp (145)"]					= { "Swamp" 	, { false, false, false, 4    , false } },
["Swamp (146)"]					= { "Swamp" 	, { false, false, false, false, 5     } },
["Mountain (147)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (148)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (149)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (150)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (151)"]				= { "Forest"	, { 1    , false, false, false, false, false } },
["Forest (152)"]				= { "Forest"	, { false, 2    , false, false, false, false } },
["Forest (153)"]				= { "Forest"	, { false, false, 3    , false, false, false } },
["Forest (154)"]				= { "Forest"	, { false, false, false, 4    , false, false } },
["Forest (155)"]				= { "Forest"	, { false, false, false, false, 5    , false } },
["Forest (156)"]				= { "Forest"	, { false, false, false, false, false, 5     } },
	},
},
[785] = { name="Duel Decks: Venser vs. Koth",
	foil="n",
	cardcount={ reg=77, tok=2, nontr=0, overs=0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3 } },
["Island"] 						= { "Island"	, { 1    , 2    , 3 } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Plains (38)"]					= { "Plains"	, { 1    , false, false } },
["Plains (39)"]					= { "Plains"	, { false, 2    , false } },
["Plains (40)"]					= { "Plains"	, { false, false, 3     } },
["Island (41)"]					= { "Island"	, { 1    , false, false } },
["Island (42)"]					= { "Island"	, { false, 2    , false } },
["Island (43)"]					= { "Island"	, { false, false, 3     } },
["Mountain (74)"]				= { "Mountain"	, { 1    , false, false, false } }, 
["Mountain (75)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (76)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (77)"]				= { "Mountain"	, { false, false, false, 4     } },
	},
	foiltweak={
["Venser, the Sojourner"]		= { foil = true},
["Koth of the Hammer"]			= { foil = true},
	},
},
[783] = { name="Premium Deck Series: Graveborn",
	foilonly=true,
	cardcount={ reg=30, tok=0, nontr=0, overs=0 }, 
	variants={
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Swamp (27)"]					= { "Swamp"		, { 1    , false, false, false } }, 
["Swamp (28)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (29)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (30)"]					= { "Swamp"		, { false, false, false, 4     } },
	},
},
[781] = { name="Duel Decks: Ajani vs. Nicol Bolas",
	foil="n",
	cardcount={ reg=80, tok=2, nontr=0, overs=0 }, 
	variants={
["Swamp"] 						= { "Swamp"		, { 1    , 2     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2     } },
["Forest"] 						= { "Forest"	, { 1    , 2     } },
["Swamp (77)"] 					= { "Swamp"		, { 1    , false } },
["Swamp (78)"] 					= { "Swamp"		, { false, 2     } },
["Mountain (41)"]				= { "Mountain"	, { 1    , false } },
["Mountain (80)"]				= { "Mountain"	, { false, 2     } },
["Forest (38)"] 				= { "Forest"	, { 1    , false } },
["Forest (39)"] 				= { "Forest"	, { false, 2     } },
	},
	foiltweak={
["Ajani Vengeant"]				= { foil = true},
["Nicol Bolas, Planeswalker"]	= { foil = true},
	},
},
[780] = { name="From the Vault: Legends",
	foilonly=true,
	cardcount={ reg=15, tok=0, nontr=0, overs=0 }, 
},
[778] = { name="Commander",
	foil="n", -- 15 oversized are foilonly
	cardcount={ reg=318, tok=0, nontr=0, overs=15 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (299)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (300)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (301)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (302)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (303)"]				= { "Island"	, { 1    , false, false, false } },
["Island (304)"]				= { "Island"	, { false, 2    , false, false } },
["Island (305)"]				= { "Island"	, { false, false, 3    , false } },
["Island (306)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (307)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (308)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (309)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (310)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (311)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (312)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (313)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (314)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (315)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (316)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (317)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (318)"]				= { "Forest"	, { false, false, false, 4     } },
	},
},
[777] = { name="Duel Decks: Knights vs. Dragons",
	foil="n",
	cardcount={ reg=81, tok=1, nontr=0, overs=0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest"	, { 1    , 2    , 3    , 4     } },
["Plains (39)"]					= { "Plains"	, { 1    , false, false, false } }, 
["Plains (40)"]					= { "Plains"	, { false, 2    , false, false } },
["Plains (41)"]					= { "Plains"	, { false, false, 3    , false } },
["Plains (42)"]					= { "Plains"	, { false, false, false, 4     } },
["Mountain (78)"]				= { "Mountain"	, { 1    , false, false, false } }, 
["Mountain (79)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (80)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (81)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (43)"]					= { "Forest"	, { 1    , false, false, false } }, 
["Forest (44)"]					= { "Forest"	, { false, 2    , false, false } },
["Forest (45)"]					= { "Forest"	, { false, false, 3    , false } },
["Forest (46)"]					= { "Forest"	, { false, false, false, 4     } },
	},
	foiltweak={
["Knight of the Reliquary"]		= { foil = true},
["Bogardan Hellkite"]			= { foil = true},
	},
},
[774] = { name="Premium Deck Series: Fire and Lightning",
	foilonly=true,
	cardcount={ reg=34, tok=0, nontr=0, overs=0 }, 
	variants={
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Mountain (31)"]				= { "Mountain"	, { 1    , false, false, false } }, 
["Mountain (32)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (33)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (34)"]				= { "Mountain"	, { false, false, false, 4     } },
	},
},
[772] = { name="Duel Decks: Elspeth vs. Tezzeret",
	foil="n",
	cardcount={ reg=79, tok=1, nontr=0, overs=0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island"	, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Plains (35)"]					= { "Plains"	, { 1    , false, false, false } },
["Plains (36)"]					= { "Plains"	, { false, 2    , false, false } },
["Plains (37)"]					= { "Plains"	, { false, false, 3    , false } },
["Plains (38)"]					= { "Plains"	, { 1    , false, false, 4     } }, 
["Island (76)"]					= { "Island"	, { 1    , false, false, false } },
["Island (77)"]					= { "Island"	, { false, 2    , false, false } },
["Island (78)"]					= { "Island"	, { false, false, 3    , false } },
["Island (79)"]					= { "Island"	, { 1    , false, false, 4     } }, 
	},
	foiltweak={
["Elspeth, Knight-Errant"]		= { foil = true},
["Tezzeret the Seeker"]			= { foil = true},
	},
},
[771] = { name="From the Vault: Relics",
	foilonly=true,
	cardcount={ reg=15, tok=0, nontr=0, overs=0 }, 
},
[769] = { name="Archenemy",
	foil="n",
	cardcount={ reg=150, tok=0, nontr=45, overs=0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (137)"]				= { "Plains"	, { 1    , false } },
["Plains (138)"]				= { "Plains"	, { false, 2     } },
["Island (139)"]				= { "Island"	, { 1    , false, false } },
["Island (140)"]				= { "Island"	, { false, 2    , false } },
["Island (141)"]				= { "Island"	, { false, false, 3     } },
["Swamp (142)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (143)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (144)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (145)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (146)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (147)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (148)"]				= { "Forest"	, { 1    , false, false } },
["Forest (149)"]				= { "Forest"	, { false, 2    , false } },
["Forest (150)"]				= { "Forest"	, { false, false, 3     } },
	},
},
[768] = { name="Duels of the Planeswalkers",
	foil="n",
	cardcount={ reg=113, tok=0, nontr=0, overs=0 }, 
	variants={
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Island (98)"]					= { "Island"	, { 1    , false, false, false } },
["Island (99)"]					= { "Island"	, { false, 2    , false, false } },
["Island (100)"]				= { "Island"	, { false, false, 3    , false } },
["Island (101)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (102)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (103)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (104)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (105)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (106)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (107)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (108)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (109)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (110)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (111)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (112)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (113)"]				= { "Forest"	, { false, false, false, 4     } },
	},
	foiltweak={
["Mahamoti Djinn"]				= { foil = true},
["Ascendant Evincar"]			= { foil = true},
["Kamahl, Pit Fighter"]			= { foil = true},
["Immaculate Magistrate"]		= { foil = true},
["Verdant Force"]				= { foil = true},
	},
},
[766] = { name="Duel Decks: Phyrexia vs. The Coalition",
	foil="n",
	cardcount={ reg=71, tok=3, nontr=0, overs=0 }, 
	variants={
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2     } },
["Swamp (32)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (33)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (34)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (35)"]					= { "Swamp"		, { false, false, false, 4     } },
["Forest (70)"]					= { "Forest"	, { 1    , false } },
["Forest (71)"]					= { "Forest"	, { false, 2     } },
	},
	foiltweak={
["Phyrexian Negator"]			= { foil = true},
["Urza’s Rage"]					= { foil = true},
	},
},
[764] = { name="Premium Deck Series: Slivers",
	foilonly=true,
	cardcount={ reg=41, tok=0, nontr=0, overs=0 }, 
},
[763] = { name="Duel Decks: Garruk vs. Liliana",
	foil="n",
	cardcount={ reg=63, tok=3, nontr=0, overs=0 }, 
	variants={
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Swamp (60)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (61)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (62)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (63)"]					= { "Swamp"		, { false, false, false, 4     } },
["Forest (28)"]					= { "Forest"	, { 1    , false, false, false } },
["Forest (29)"]					= { "Forest"	, { false, 2    , false, false } },
["Forest (30)"]					= { "Forest"	, { false, false, 3    , false } },
["Forest (31)"]					= { "Forest"	, { false, false, false, 4     } },
["Beast"] 						= { "Beast" 	, { 1    , 2     } },
["Beast (1)"]					= { "Beast" 	, { 1    , false } },-- 3/3
["Beast (2)"]					= { "Beast" 	, { false, 2     } },-- 4/4
	},
	foiltweak={
["Garruk Wildspeaker"]			= { foil = true},
["Liliana Vess"]				= { foil = true},
	},
},
[761] = { name="Planechase",
	foil="n",
	cardcount={ reg=169, tok=0, nontr=40, overs=0 }, 
	variants={
["Plains"] 						= { "Plains" 	, { 1    , 2    , 3    , 4    , 5     } },
["Island"] 						= { "Island"	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4    , 5     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4    , 5    , 6    , 7    , 8   , 9     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4    , 5     } },
["Plains (142)"]				= { "Plains"	, { 1    , false, false, false, false } },
["Plains (143)"]				= { "Plains"	, { false, 2    , false, false, false } },
["Plains (144)"]				= { "Plains"	, { false, false, 3    , false, false } },
["Plains (145)"]				= { "Plains"	, { false, false, false, 4    , false } },
["Plains (146)"]				= { "Plains"	, { false, false, false, false, 5     } },
["Island (147)"]				= { "Island"	, { 1    , false, false, false } }, 
["Island (148)"]				= { "Island"	, { false, 2    , false, false } },
["Island (149)"]				= { "Island"	, { false, false, 3    , false } },
["Island (150)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (151)"]					= { "Swamp"		, { 1    , false, false, false, false } },
["Swamp (152)"]					= { "Swamp"		, { false, 2    , false, false, false } },
["Swamp (153)"]					= { "Swamp"		, { false, false, 3    , false, false } },
["Swamp (154)"]					= { "Swamp"		, { false, false, false, 4    , false } },
["Swamp (155)"]					= { "Swamp"		, { false, false, false, false, 5     } },
["Mountain (156)"]				= { "Mountain"	, { 1    , false, false, false, false, false, false, false, false } },
["Mountain (157)"]				= { "Mountain"	, { false, 2    , false, false, false, false, false, false, false } },
["Mountain (158)"]				= { "Mountain"	, { false, false, 3    , false, false, false, false, false, false } },
["Mountain (159)"]				= { "Mountain"	, { false, false, false, 4    , false, false, false, false, false } },
["Mountain (160)"]				= { "Mountain"	, { false, false, false, false, 5    , false, false, false, false } },
["Mountain (161)"]				= { "Mountain"	, { false, false, false, false, false, 6    , false, false, false } },
["Mountain (162)"]				= { "Mountain"	, { false, false, false, false, false, false, 7    , false, false } },
["Mountain (163)"]				= { "Mountain"	, { false, false, false, false, false, false, false, 8    , false } },
["Mountain (164)"]				= { "Mountain"	, { false, false, false, false, false, false, false, false, 9     } },
["Forest (165)"]				= { "Forest"	, { 1    , false, false, false, false } },
["Forest (166)"]				= { "Forest"	, { false, 2    , false, false, false } },
["Forest (167)"]				= { "Forest"	, { false, false, 3    , false, false } },
["Forest (168)"]				= { "Forest"	, { false, false, false, 4    , false } },
["Forest (169)"]				= { "Forest"	, { false, false, false, false, 5     } },
	},
},
[760] = { name="From the Vault: Exiled",
	foilonly=true,
	cardcount={ reg=15, tok=0, nontr=0, overs=0 }, 
},
[757] = { name="Duel Decks: Divine vs. Demonic",
	foil="n",
	cardcount={ reg=62, tok=3, nontr=0, overs=0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Plains (26)"]					= { "Plains"	, { 1    , false, false, false } },
["Plains (27)"]					= { "Plains"	, { false, 2    , false, false } },
["Plains (28)"]					= { "Plains"	, { false, false, 3    , false } },
["Plains (29)"]					= { "Plains"	, { false, false, false, 4     } },
["Swamp (59)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (60)"] 					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (61)"] 					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (62)"] 					= { "Swamp"		, { false, false, false, 4     } },
	},
	foiltweak={
["Akroma, Angel of Wrath"]		= { foil = true},
["Lord of the Pit"]				= { foil = true},
	},
},
[755] = { name="Duel Decks: Jace vs. Chandra",
	foil="n",
	cardcount={ reg=62, tok=1, nontr=0, overs=0 }, 
	variants={
["Island"] 						= { "Island"	, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Island (30)"]					= { "Island"	, { 1    , false, false, false } },
["Island (31)"]					= { "Island"	, { false, 2    , false, false } },
["Island (32)"]					= { "Island"	, { false, false, 3    , false } },
["Island (33)"]					= { "Island"	, { false, false, false, 4     } },
["Mountain (59)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (60)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (61)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (62)"]				= { "Mountain"	, { false, false, false, 4     } },
	},
	foiltweak={
["Jace Beleren"]				= { foil = true},
["Chandra Nalaar"]				= { foil = true},
	},
},
[753] = { name="From the Vault: Dragons",
	foilonly=true,
	cardcount={ reg=15, tok=0, nontr=0, overs=0 }, 
},
[740] = { name="Duel Decks: Elves vs. Goblins   ",
	foil="n",
	cardcount={ reg=62, tok=3, nontr=0, overs=0 }, 
	variants={
["Forest"] 						= { "Forest"	, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest (28)"]					= { "Forest"	, { 1    , false, false, false } },
["Forest (29)"]					= { "Forest"	, { false, 2    , false, false } },
["Forest (30)"]					= { "Forest"	, { false, false, 3    , false } },
["Forest (31)"]					= { "Forest"	, { false, false, false, 4     } },
["Mountain (59)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (60)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (61)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (62)"]				= { "Mountain"	, { false, false, false, 4     } },
	},
	foiltweak={
["Ambush Commander"]			= { foil = true},
["Siege-Gang Commander"]					= { foil = true},
	},
},
[675] = { name="Coldsnap Theme Decks",
	foil="n",
	cardcount={ reg=62, tok=0, nontr=0, overs=0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (369)"]				= { "Plains"	, { 1    , false, false } },
["Plains (370)"]				= { "Plains"	, { false, 2    , false } },
["Plains (371)"]				= { "Plains"	, { false, false, 3     } },
["Island (372)"]				= { "Island"	, { 1    , false, false } },
["Island (373)"]				= { "Island"	, { false, 2    , false } },
["Island (374)"]				= { "Island"	, { false, false, 3     } },
["Swamp (375)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (376)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (377)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (378)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (379)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (380)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (381)"]				= { "Forest"	, { 1    , false, false } },
["Forest (382)"]				= { "Forest"	, { false, 2    , false } },
["Forest (383)"]				= { "Forest"	, { false, false, 3     } },
	},
},
[636] = { name="Salvat 2011",
	foil="n",
	cardcount={ reg=224, tok=0, nontr=0, overs=0 },
	lang={ [7]=true },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (205)"]				= { "Plains"	, { 1    , false ,false, false } }, 
["Plains (206)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (207)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (208)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (209)"]				= { "Island"	, { 1    , false, false, false } },
["Island (210)"]				= { "Island"	, { false, 2    , false, false } },
["Island (211)"]				= { "Island"	, { false, false, 3    , false } },
["Island (212)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (213)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (214)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (215)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (216)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (217)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (218)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (219)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (220)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (221)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (222)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (223)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (224)"]				= { "Forest"	, { false, false, false, 4     } }
	},
},
[635] = { name="Salvat Magic Encyclopedia",
	foil="n",
	cardcount={ reg=600, tok=0, nontr=0, overs=0 }, 
--	variants={
--TODO [635] variant table based on ITA
--	},
},
[600] = { name="Unhinged",
	foil="y",
	cardcount={ reg = 141, tok = 0 },
	variants={},
	foiltweak={
["Super Secret Tech"]			= { foil = true},
	},
},
[490] = { name="Deckmasters",
	foil="n",
	cardcount={ reg=58, tok=0, nontr=0, overs=0 }, 
	variants={
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Swamp (42)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (43)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (44)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (45)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (46)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (47)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (48)"]					= { "Forest"	, { 1    , false, false } },
["Forest (49)"]					= { "Forest"	, { false, 2    , false } },
["Forest (50)"]					= { "Forest"	, { false, false, 3     } },
["Lim-Dûl’s High Guard"] 		= { "Lim-Dûl’s High Guard"	, { 1    , 2     } },
["Lim-Dûl’s High Guard (6a)"] 	= { "Lim-Dûl’s High Guard"	, { 1    , false } },
["Lim-Dûl’s High Guard (6b)"] 	= { "Lim-Dûl’s High Guard"	, { false, 2     } },
["Phantasmal Fiend"] 			= { "Phantasmal Fiend"		, { 1    , 2     } },
["Phantasmal Fiend (8a)"] 		= { "Phantasmal Fiend"		, { 1    , false } },
["Phantasmal Fiend (8b)"] 		= { "Phantasmal Fiend"		, { false, 2     } },
["Guerrilla Tactics"] 			= { "Guerrilla Tactics"		, { 1    , 2     } },
["Guerrilla Tactics (13a)"]		= { "Guerrilla Tactics"		, { 1    , false } },
["Guerrilla Tactics (13b)"]		= { "Guerrilla Tactics"		, { false, 2     } },
--["Incinerate"] 				= { "Incinerate"			, { 1    , 2     } },
--["Incinerate (regular)"] 		= { "Incinerate"			, { 1    , false } },
["Incinerate"] 					= { "Incinerate"			, { 1    , false } },
["Incinerate (premium)"] 		= { "Incinerate"			, { false, 2     } },
["Storm Shaman"] 				= { "Storm Shaman"			, { 1    , 2     } },
["Storm Shaman (21a)"] 			= { "Storm Shaman"			, { 1    , false } },
["Storm Shaman (21b)"] 			= { "Storm Shaman"			, { false, 2     } },
["Yavimaya Ancients"] 			= { "Yavimaya Ancients"		, { 1    , 2     } },
["Yavimaya Ancients (31a)"]		= { "Yavimaya Ancients"		, { 1    , false } },
["Yavimaya Ancients (31b)"]		= { "Yavimaya Ancients"		, { false, 2     } },
--["Icy Manipulator"] 			= { "Icy Manipulator"		, { 1    , 2     } },
--["Icy Manipulator (regular)"] = { "Icy Manipulator"		, { 1    , false } },
["Icy Manipulator"] 			= { "Icy Manipulator"		, { 1    , false } },
["Icy Manipulator (premium)"] 	= { "Icy Manipulator"		, { false, 2     } },
["Phyrexian War Beast"] 		= { "Phyrexian War Beast"	, { 1    , 2     } },
["Phyrexian War Beast (37a)"] 	= { "Phyrexian War Beast"	, { 1    , false } },
["Phyrexian War Beast (37b)"] 	= { "Phyrexian War Beast"	, { false, 2     } },
	},
	foiltweak={
["Necropotence"]				= { foil = true},
["Incinerate (premium)"]		= { foil = true},
["Lhurgoyf"]					= { foil = true},
["Icy Manipulator (premium)"]	= { foil = true},
	},
},
[440] = { name="Beatdown Box Set",
	foil="n",
	cardcount={ reg=90, tok=0, nontr=0, overs=0 }, 
	variants={
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Island (79)"]					= { "Island"	, { 1    , false, false } },
["Island (80)"]					= { "Island"	, { false, 2    , false } },
["Island (81)"]					= { "Island"	, { false, false, 3     } },
["Swamp (82)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (83)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (84)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (85)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (86)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (87)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (88)"]					= { "Forest"	, { 1    , false, false } },
["Forest (89)"]					= { "Forest"	, { false, 2    , false } },
["Forest (90)"]					= { "Forest"	, { false, false, 3     } },
	},
	foiltweak={
["Erhnam Djinn"]				= { foil = true},
["Sengir Vampire"]				= { foil = true},
	},
},
[415] = { name="Starter 2000",
	foil="n",
	cardcount={ reg=20, tok=0, nontr=0, overs=0 }, 
	foiltweak={
["Rhox"]						= { foil = true},
	},
},
[405] = { name="Battle Royale Box Set",
	foil="n",
	cardcount={ reg=136, tok=0, nontr=0, overs=0 }, 
	variants={
["Plains"] 				= { "Plains"	, { 1    , 2    , 3    , 4    , 5    , 6    , 7    , 8   , 9     } },
["Island"] 				= { "Island"	, { 1    , 2    , 3    , 4    , 5 } },
["Swamp"] 				= { "Swamp"		, { 1    , 2    , 3    , 4 } },
["Mountain"] 			= { "Mountain"	, { 1    , 2    , 3    , 4    , 5    , 6    , 7    , 8   , 9     } },
["Forest"] 				= { "Forest"	, { 1    , 2    , 3    , 4    , 5    , 6    , 7    , 8   , 9     } },
["Plains (1)"]			= { "Plains"	, { 1    , false, false, false, false, false, false, false, false } },
["Plains (2)"]			= { "Plains"	, { false, 2    , false, false, false, false, false, false, false } },
["Plains (3)"]			= { "Plains"	, { false, false, 3    , false, false, false, false, false, false } },
["Plains (4)"]			= { "Plains"	, { false, false, false, 4    , false, false, false, false, false } },
["Plains (5)"]			= { "Plains"	, { false, false, false, false, 5    , false, false, false, false } },
["Plains (6)"]			= { "Plains"	, { false, false, false, false, false, 6    , false, false, false } },
["Plains (7)"]			= { "Plains"	, { false, false, false, false, false, false, 7    , false, false } },
["Plains (8)"]			= { "Plains"	, { false, false, false, false, false, false, false, 8    , false } },
["Plains (9)"]			= { "Plains"	, { false, false, false, false, false, false, false, false, 9     } },
["Island (1)"]			= { "Island"	, { 1    , false, false, false, false } },
["Island (2)"]			= { "Island"	, { false, 2    , false, false, false } },
["Island (3)"]			= { "Island"	, { false, false, 3    , false, false } },
["Island (4)"]			= { "Island"	, { false, false, false, 4    , false } },
["Island (5)"]			= { "Island"	, { false, false, false, false, 5     } },
["Swamp (1)"]			= { "Swamp"		, { 1    , false, false, false } },
["Swamp (2)"]			= { "Swamp"		, { false, 2    , false, false } },
["Swamp (3)"]			= { "Swamp"		, { false, false, 3    , false } },
["Swamp (4)"]			= { "Swamp"		, { false, false, false, 4     } },
["Mountain (1)"]		= { "Mountain"	, { 1    , false, false, false, false, false, false, false, false } },
["Mountain (2)"]		= { "Mountain"	, { false, 2    , false, false, false, false, false, false, false } },
["Mountain (3)"]		= { "Mountain"	, { false, false, 3    , false, false, false, false, false, false } },
["Mountain (4)"]		= { "Mountain"	, { false, false, false, 4    , false, false, false, false, false } },
["Mountain (5)"]		= { "Mountain"	, { false, false, false, false, 5    , false, false, false, false } },
["Mountain (6)"]		= { "Mountain"	, { false, false, false, false, false, 6    , false, false, false } },
["Mountain (7)"]		= { "Mountain"	, { false, false, false, false, false, false, 7    , false, false } },
["Mountain (8)"]		= { "Mountain"	, { false, false, false, false, false, false, false, 8    , false } },
["Mountain (9)"]		= { "Mountain"	, { false, false, false, false, false, false, false, false, 9     } },
["Forest (1)"]			= { "Forest"	, { 1    , false, false, false, false, false, false, false, false } },
["Forest (2)"]			= { "Forest"	, { false, 2    , false, false, false, false, false, false, false } },
["Forest (3)"]			= { "Forest"	, { false, false, 3    , false, false, false, false, false, false } },
["Forest (4)"]			= { "Forest"	, { false, false, false, 4    , false, false, false, false, false } },
["Forest (5)"]			= { "Forest"	, { false, false, false, false, 5    , false, false, false, false } },
["Forest (6)"]			= { "Forest"	, { false, false, false, false, false, 6    , false, false, false } },
["Forest (7)"]			= { "Forest"	, { false, false, false, false, false, false, 7    , false, false } },
["Forest (8)"]			= { "Forest"	, { false, false, false, false, false, false, false, 8    , false } },
["Forest (9)"]			= { "Forest"	, { false, false, false, false, false, false, false, false, 9     } },
	},
},
[390] = { name="Starter 1999",
	foil="n",
	cardcount={ reg=173, tok=0, nontr=0, overs=0 }, 
	variants={
["Plains"] 					= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 					= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 					= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 				= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 					= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (154)"]			= { "Plains"	, { 1    , false, false, false } }, 
["Plains (155)"]			= { "Plains"	, { false, 2    , false, false } },
["Plains (156)"]			= { "Plains"	, { false, false, 3    , false } },
["Plains (157)"]			= { "Plains"	, { false, false, false, 4     } },
["Island (158)"]			= { "Island"	, { 1    , false, false, false } },
["Island (159)"]			= { "Island"	, { false, 2    , false, false } },
["Island (160)"]			= { "Island"	, { false, false, 3    , false } },
["Island (161)"]			= { "Island"	, { false, false, false, 4     } },
["Swamp (162)"]				= { "Swamp"		, { 1    , false, false, false } },
["Swamp (163)"]				= { "Swamp"		, { false, 2    , false, false } },
["Swamp (164)"]				= { "Swamp"		, { false, false, 3    , false } },
["Swamp (165)"]				= { "Swamp"		, { false, false, false, 4     } },
["Mountain (166)"]			= { "Mountain"	, { 1    , false, false, false } },
["Mountain (167)"]			= { "Mountain"	, { false, 2    , false, false } },
["Mountain (168)"]			= { "Mountain"	, { false, false, 3    , false } },
["Mountain (169)"]			= { "Mountain"	, { false, false, false, 4     } },
["Forest (170)"]			= { "Forest"	, { 1    , false, false, false } },
["Forest (171)"]			= { "Forest"	, { false, 2    , false, false } },
["Forest (172)"]			= { "Forest"	, { false, false, 3    , false } },
["Forest (173)"]			= { "Forest"	, { false, false, false, 4     } },
	},
},
[380] = { name="Portal Three Kingdoms",
	foil="n",
	cardcount={ reg = 180, tok = 0 }, -- Portal Three Kingdoms
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (166)"]				= { "Plains"	, { 1    , false, false } },
["Plains (167)"]				= { "Plains"	, { false, 2    , false } },
["Plains (168)"]				= { "Plains"	, { false, false, 3     } },
["Island (169)"]				= { "Island"	, { 1    , false, false } },
["Island (170)"]				= { "Island"	, { false, 2    , false } },
["Island (171)"]				= { "Island"	, { false, false, 3     } },
["Swamp (172)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (173)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (174)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (175)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (176)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (177)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (178)"]				= { "Forest"	, { 1    , false, false } },
["Forest (179)"]				= { "Forest"	, { false, 2    , false } },
["Forest (180)"]				= { "Forest"	, { false, false, 3     } },
	},
},
[340] = { name="Anthologies",
	foil="n",
	cardcount={ reg=85, tok=0, nontr=0, overs=0 }, 
	variants={
["Plains"] 						= { "Plains" 	, { 1    , 2     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2     } },
["Forest"] 						= { "Forest" 	, { 1    , 2     } },
["Plains (1)"]					= { "Plains"	, { 1    , false } },
["Plains (2)"]					= { "Plains"	, { false, 2     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2     } },
["Forest (1)"]					= { "Forest"	, { 1    , false } },
["Forest (2)"]					= { "Forest"	, { false, 2     } },
	},
},
[325] = { name="Multiverse Gift Box",
	foil="n",
	cardcount={ reg = 10 , tok = 0 },
},
[320] = { name="Unglued",
	foil="n",
	cardcount={ reg = 88 , tok = 6 },
	variants={
["B.F.M."] 						= { "B.F.M."	, { "Left", "Right" } },
["B.F.M. (Left)"] 				= { "B.F.M."	, { "Left", false   } },
["B.F.M. (Right)"] 				= { "B.F.M."	, { false , "Right" } },
	},
},
[310] = { name="Portal Second Age",
	foil="n",
	cardcount={ reg = 165, tok = 0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false } },
["Plains (2)"]					= { "Plains"	, { false, 2    , false } },
["Plains (3)"]					= { "Plains"	, { false, false, 3     } },
["Island (1)"]					= { "Island"	, { 1    , false, false } },
["Island (2)"]					= { "Island"	, { false, 2    , false } },
["Island (3)"]					= { "Island"	, { false, false, 3     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (3)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (3)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (1)"]					= { "Forest"	, { 1    , false, false } },
["Forest (2)"]					= { "Forest"	, { false, 2    , false } },
["Forest (3)"]					= { "Forest"	, { false, false, 3     } },
	},
},
[260] = { name="Portal",
	foil="n",
	cardcount={ reg = 228, tok = 0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false, false } }, 
["Plains (2)"]					= { "Plains"	, { false, 2    , false, false } },
["Plains (3)"]					= { "Plains"	, { false, false, 3    , false } },
["Plains (4)"]					= { "Plains"	, { false, false, false, 4     } },
["Island (1)"]					= { "Island"	, { 1    , false, false, false } },
["Island (2)"]					= { "Island"	, { false, 2    , false, false } },
["Island (3)"]					= { "Island"	, { false, false, 3    , false } },
["Island (4)"]					= { "Island"	, { false, false, false, 4     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (3)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (4)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (3)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (4)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (1)"]					= { "Forest"	, { 1    , false, false, false } },
["Forest (2)"]					= { "Forest"	, { false, 2    , false, false } },
["Forest (3)"]					= { "Forest"	, { false, false, 3    , false } },
["Forest (4)"]					= { "Forest"	, { false, false, false, 4     } },
["Anaconda"]					= { "Anaconda"				, { ""	 , false } },
["Anaconda (ST)"]				= { "Anaconda"				, { false, "ST"	 } },
["Blaze"]						= { "Blaze"					, { ""	 , false } },
["Blaze (ST)"]					= { "Blaze"					, { false, "ST"	 } },
["Elite Cat Warrior"]			= { "Elite Cat Warrior"		, { ""	 , false } },
["Elite Cat Warrior (ST)"]		= { "Elite Cat Warrior"		, { false, "ST"	 } },
["Hand of Death"]				= { "Hand of Death"			, { ""	 , false } },
["Hand of Death (ST)"]			= { "Hand of Death"			, { false, "ST"	 } },
["Monstrous Growth"]			= { "Monstrous Growth"		, { ""	 , false } },
["Monstrous Growth (ST)"]		= { "Monstrous Growth"		, { false, "ST"	 } },
["Raging Goblin"]				= { "Raging Goblin"			, { ""	 , false } },
["Raging Goblin (ST)"]			= { "Raging Goblin"			, { false, "ST"	 } },
["Warrior's Charge"]			= { "Warrior's Charge"		, { ""	 , false } },
["Warrior's Charge (ST)"]		= { "Warrior's Charge"		, { false, "ST"	 } },
["Armored Pegasus"]				= { "Armored Pegasus"		, { ""	 , false } },
["Armored Pegasus (DG)"]		= { "Armored Pegasus"		, { false, "DG"	 } },
["Bull Hippo"]					= { "Bull Hippo"			, { ""	 , false } },
["Bull Hippo (DG)"]				= { "Bull Hippo"			, { false, "DG"	 } },
["Cloud Pirates"]				= { "Cloud Pirates"			, { ""	 , false } },
["Cloud Pirates (DG)"]			= { "Cloud Pirates"			, { false, "DG"	 } },
["Feral Shadow"]				= { "Feral Shadow"			, { ""	 , false } },
["Feral Shadow (DG)"]			= { "Feral Shadow"			, { false, "DG"	 } },
["Snapping Drake"]				= { "Snapping Drake"		, { ""	 , false } },
["Snapping Drake (DG)"]			= { "Snapping Drake"		, { false, "DG"	 } },
["Storm Crow"]					= { "Storm Crow"			, { ""	 , false } },
["Storm Crow (DG)"]				= { "Storm Crow"			, { false, "DG"	 } },
["Anakonda"]					= { "Anakonda"				, { ""	 , false } },
["Anakonda (ST)"]				= { "Anakonda"				, { false, "ST"	 } },
["Heiße Glut"]					= { "Heiße Glut"			, { ""	 , false } },
["Heiße Glut (ST)"]				= { "Heiße Glut"			, { false, "ST"	 } },
["Katzenkriegerelite"]			= { "Katzenkriegerelite"	, { ""	 , false } },
["Katzenkriegerelite (ST)"]		= { "Katzenkriegerelite"	, { false, "ST"	 } },
["Todbringende Hand"]			= { "Todbringende Hand"		, { ""	 , false } },
["Todbringende Hand (ST)"]		= { "Todbringende Hand"		, { false, "ST"	 } },
["Unheimliches Wachstum"]		= { "Unheimliches Wachstum"	, { ""	 , false } },
["Unheimliches Wachstum (ST)"]	= { "Unheimliches Wachstum"	, { false, "ST"	 } },
["Wütender Goblin"]				= { "Wütender Goblin"		, { ""	 , false } },
["Wütender Goblin (ST)"]		= { "Wütender Goblin"		, { false, "ST"	 } },
["Attacke der Krieger"]			= { "Attacke der Krieger"	, { ""	 , false } },
["Attacke der Krieger (ST)"]	= { "Attacke der Krieger"	, { false, "ST"	 } },
	},
},
[235] = { name="Multiverse Gift Box",
	foil="n",
	cardcount={ reg=10, tok=0, nontr=0, overs=0 }, 
},
[225] = { name="Introductory Two-Player Set",
	foil="n",
	cardcount={ reg=67, tok=0, nontr=0, overs=0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false } },
["Plains (2)"]					= { "Plains"	, { false, 2    , false } },
["Plains (3)"]					= { "Plains"	, { false, false, 3     } },
["Island (1)"]					= { "Island"	, { 1    , false, false } },
["Island (2)"]					= { "Island"	, { false, 2    , false } },
["Island (3)"]					= { "Island"	, { false, false, 3     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (3)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (3)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (1)"]					= { "Forest"	, { 1    , false, false } },
["Forest (2)"]					= { "Forest"	, { false, 2    , false } },
["Forest (3)"]					= { "Forest"	, { false, false, 3     } },
	},
},
[201] = { name="Renaissance",-- (GER)
	foil="n",
	cardcount={ reg = 122, tok = 0 },
},
[200] = { name="Chronicles",
	foil="n",
	cardcount={ reg = 125, tok = 0 },
	variants={
["Urza's Mine"] 				= { "Urza's Mine"			, { 1    , 2    , 3    , 4 } },
["Urza's Power Plant"] 			= { "Urza's Power Plant"	, { 1    , 2    , 3    , 4 } },
["Urza's Tower"] 				= { "Urza's Tower"			, { 1    , 2    , 3    , 4 } },
["Urza's Mine (1)"] 			= { "Urza's Mine"			, { 1    , false, false, false } },--Mouth
["Urza's Mine (2)"] 			= { "Urza's Mine"			, { false, 2    , false, false } },--Clawed Sphere
["Urza's Mine (3)"] 			= { "Urza's Mine"			, { false, false, 3    , false } },--Pully
["Urza's Mine (4)"] 			= { "Urza's Mine"			, { false, false, false, 4     } },--Tower
["Urza's Power Plant (1)"] 		= { "Urza's Power Plant"	, { 1    , false, false, false } },--Rock in Pot
["Urza's Power Plant (2)"] 		= { "Urza's Power Plant"	, { false, 2    , false, false } },--Columns
["Urza's Power Plant (3)"] 		= { "Urza's Power Plant"	, { false, false, 3    , false } },--Bug
["Urza's Power Plant (4)"] 		= { "Urza's Power Plant"	, { false, false, false, 4     } },--Sphere
["Urza's Tower (1)"] 			= { "Urza's Tower"			, { 1    , false, false, false } },--Forest
["Urza's Tower (2)"] 			= { "Urza's Tower"			, { false, 2    , false, false } },--Plains
["Urza's Tower (3)"] 			= { "Urza's Tower"			, { false, false, 3    , false } },--Mountains
["Urza's Tower (4)"] 			= { "Urza's Tower"			, { false, false, false, 4     } },--Shore
	},
},
[106] = { name="Collectors’ Edition (International)",
	foil="n",
	cardcount={ reg=0, tok=0, nontr=0, rep=302 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false } },
["Plains (2)"]					= { "Plains"	, { false, 2    , false } },
["Plains (3)"]					= { "Plains"	, { false, false, 3     } },
["Island (1)"]					= { "Island"	, { 1    , false, false } },
["Island (2)"]					= { "Island"	, { false, 2    , false } },
["Island (3)"]					= { "Island"	, { false, false, 3     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (3)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (3)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (1)"]					= { "Forest"	, { 1    , false, false } },
["Forest (2)"]					= { "Forest"	, { false, 2    , false } },
["Forest (3)"]					= { "Forest"	, { false, false, 3     } },
	},
},
[105] = { name="Collectors’ Edition (Domestic)",
	foil="n",
	cardcount={ reg=0, tok=0, nontr=0, rep=302 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false } },
["Plains (2)"]					= { "Plains"	, { false, 2    , false } },
["Plains (3)"]					= { "Plains"	, { false, false, 3     } },
["Island (1)"]					= { "Island"	, { 1    , false, false } },
["Island (2)"]					= { "Island"	, { false, 2    , false } },
["Island (3)"]					= { "Island"	, { false, false, 3     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (3)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (3)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (1)"]					= { "Forest"	, { 1    , false, false } },
["Forest (2)"]					= { "Forest"	, { false, 2    , false } },
["Forest (3)"]					= { "Forest"	, { false, false, 3     } },
	},
},
[70] = { name="Vanguard",
	foil="n",
	cardcount={ reg=0, tok=0, nontr=32, overs=0 }, 
},
[69] = { name="Box Topper Cards",
	foil="n",
	cardcount={ reg=0, tok=0, nontr=0, overs=52 }, 
	variants={
["Ambition’s Cost"]			= { "8ED" },
["Avatar of Hope"]			= { "8ED", "PRM" },
["Blinding Angel"]			= { "8ED" },
["Clone"]					= { "9ED" },
["Curiosity"]				= { "8ED" },
["Diabolic Tutor"]			= { "8ED" },
["Enrage"]					= { "8ED" },
["Force of Nature"]			= { "9ED" },
["Furnace of Rath"]			= { "8ED" },
["Guerrilla Tactics"]		= { "8ED" },
["Hell’s Caretaker"]		= { "9ED" },
["Hypnotic Specter"]		= { "9ED" },
["Icy Manipulator"]			= { "9ED" },
["Intruder Alarm"]			= { "8ED" },
["Jester’s Cap"]			= { "9ED" },
["Kird Ape"]				= { "9ED" },
["Llanowar Behemoth"]		= { "8ED" },
["Llanowar Elves"]			= { "9ED" },
["Lord of the Undead"]		= { "8ED", "PRM" },
["Mahamoti Djinn"]			= { "9ED" },
["Merchant of Secrets"]		= { "8ED" },
["Merchant Scroll"]			= { "8ED" },
["Mind Bend"]				= { "8ED" },
["Mind Sludge"]				= { "8ED" },
["Naturalize"]				= { "8ED" },
["Nekrataal"]				= { "8ED" },
["Obliterate"]				= { "8ED", "PRM" },
["Orcish Spy"]				= { "8ED" },
["Paladin en-Vec"]			= { "9ED" },
["Phyrexian Arena"]			= { "8ED" },
["Phyrexian Plaguelord"]	= { "8ED", "PRM" },
["Plow Under"]				= { "8ED" },
["Primeval Force"]			= { "8ED" },
["Rathi Dragon"]			= { "9ED" },
["Rewind"]					= { "8ED" },
["Rukh Egg"]				= { "8ED" },
["Sage of Lat-Nam"]			= { "8ED" },
["Savannah Lions"]			= { "8ED", "PRM" },
["Serra Angel"]				= { "9ED" },
["Skull of Orm"]			= { "8ED" },
["Suntail Hawk"]			= { "8ED" },
["Two-Headed Dragon"]		= { "8ED", "PRM" },
["Underworld Dreams"]		= { "8ED" },
["Vampiric Spirit"]			= { "8ED" },
["Verdant Force"]			= { "9ED" },
["Vexing Arcanix"]			= { "8ED" },
	},
},
---not really a seperate subtable, just a bookmark for quick navigation in eclipse.
-- @field [parent=#Data.sets] #table Promos
Promos = nil,
[50] = { name="Full Box Promotion",
--TODO [50]
--	foil="",
--	cardcount={ reg=0, tok=0, nontr=0, overs=0 }, 
--	variants={
--	},
},
[45] = { name="Magic Premiere Shop",
--TODO [45]
--	foil="",
--	cardcount={ reg=0, tok=0, nontr=0, overs=0 }, 
--	variants={
--	},
},
[43] = { name="Two-Headed Giant Promos",
--TODO [43]
--	foil="",
--	cardcount={ reg=0, tok=0, nontr=0, overs=0 }, 
--	variants={
--	},
},
[42] = { name="Summer of Magic Promos",
--TODO [42]
--	foil="",
--	cardcount={ reg=0, tok=0, nontr=0, overs=0 }, 
--	variants={
--	},
},
[41] = { name="Happy Holidays Promos",
--TODO [41]
--	foil="",
--	cardcount={ reg=0, tok=0, nontr=0, overs=0 }, 
--	variants={
--	},
},
[40] = { name="Arena Promos",
--TODO [40]
--	foil="",
--	cardcount={ reg=0, tok=0, nontr=0, overs=0 }, 
--	variants={
--	},
},
[33] = { name="Championships Prizes",
--TODO [33]
--	foil="",
--	cardcount={ reg=0, tok=0, nontr=0, overs=0 }, 
--	variants={
--	},
},
[32] = { name="Pro Tour Promos",
--TODO [32]
--	foil="",
--	cardcount={ reg=0, tok=0, nontr=0, overs=0 }, 
--	variants={
--	},
},
[31] = { name="Grand Prix Promos",
	foilonly=true,
	cardcount={ reg=8, tok=0, nontr=0, overs=0 }, 
},
[30] = { name="Friday Night Magic Promos",
	foilonly=true,
	cardcount={ reg=167, tok=1, nontr=0, overs=0 }, 
	foiltweak={
["Human|Wolf"] 				= { foil = false},
	},
},
[27] = { name="Alternate Art Lands",
--TODO [27]
--	foil="",
--	cardcount={ reg=0, tok=0, nontr=0, overs=0 }, 
--	variants={
--	},
},
[26] = { name="Game Day Promos",
	foil="y",--some no, some only, no yes
	cardcount={ reg=42, tok=0, nontr=2, overs=0 }, 
	foiltweak={
["Black Sun’s Zenith"] 				= { foil = true},
["Cryptborn Horror"] 				= { foil = true},
["Deathless Angel"] 				= { foil = true},
["Dictate of Kruphix"] 				= { foil = true},
["Dungrove Elder"] 					= { foil = true},
["Elite Inquisitor"] 				= { foil = true},
["Emeria Angel"] 					= { foil = true},
["Firemane Av"] 					= { foil = true},
["Goblin Diplomats"] 				= { foil = true},
["Kalastria Highborn"] 				= { foil = true},
["Killing Wave"] 					= { foil = true},
["Magmaquake"] 						= { foil = true},
["Melek, Izzet Paragon"] 			= { foil = true},
["Mitotic Slime"] 					= { foil = true},
["Mycoid Shepherd"] 				= { foil = true},
["Myr Superion"] 					= { foil = true},
["Naya Sojourners"] 				= { foil = true},
["Nighthowler"] 					= { foil = true},
["Pain Seer"] 						= { foil = true},
["Reya Dawnbringer"] 				= { foil = true},
["Tempered Steel"] 					= { foil = true},
["Zombie Apocalypse"] 				= { foil = true},
	},
},
[25] = { name="Judge Promos",
	foilonly=true,
	cardcount={ reg=70, tok=1, nontr=0, overs=0 }, 
	foiltweak={
["Centaur"]				= { foil = false},
["Golem"]				= { foil = false},
	},
},
[24] = { name="Champs Promos",
	foilonly=true,
	cardcount={ reg=12, tok=0, nontr=0, overs=0 }, 
	foiltweak={
["Electrolyze"]						= { foil = false},
["Rakdos Guildmage"]				= { foil = false},
["Urza’s Factory"]					= { foil = false},
["Blood Knight"]					= { foil = false},
["Imperious Perfect"]				= { foil = false},
["Bramblewood Paragon"]				= { foil = false},
	},
},
[23] = { name="Gateway & WPN Promos",
	foilonly=true,
	cardcount={ reg=56, tok=0, nontr=7, overs=0 }, 
	foiltweak={
["Drench the Soil in Their Blood"]	= { foil = false},
["Horizon Boughs"]					= { foil = false},
["Imprison This Insolent Wretch"]	= { foil = false},
["Mirrored Depths"]					= { foil = false},
["Perhaps You’ve Met My Cohort"]	= { foil = false},
["Tember City"]						= { foil = false},
["Your Inescapable Doom"]			= { foil = false},
	},
},
[22] = { name="Prerelease Cards",
	foil="y",-- "o" might be better to catch most foils, but there are 5 "yes" cards in here...
	cardcount={ reg=66, tok=1, nontr=1, overs=5 }, 
	variants={
["Lu Bu, Master-at-Arms"] 			= { "Lu Bu, Master-at-Arms"		, { "April", "July" } },
["Lu Bu, Master-at-Arms (April)"] 	= { "Lu Bu, Master-at-Arms"		, { "April", false  } },
["Lu Bu, Master-at-Arms (July"] 	= { "Lu Bu, Master-at-Arms"		, { false  , "July" } },
["Plains"] 							= { "Plains"		, { "DGM" } },
	},
	foiltweak={
--TODO [22] add all foil=only to foiltweak	
["Lu Bu, Master-at-Arms"]			= { foil = false},
["Revenant"]						= { foil = false},
["Dirtcowl Wurm"]					= { foil = false},
["Celestine Reef"]					= { foil = false},
["Monstrous Hound"]					= { foil = false},
	},
},
[21] = { name="Release & Launch Party Cards",
	foilonly=true,
	cardcount={ reg=34, tok=1, nontr=0, overs=6 }, 
	foiltweak={
["Incoming!"]						= { foil = false},
["Tazeem"]							= { foil = false},
["Plots that Span Centuries"]		= { foil = false},
["Stairs to Infinity"]				= { foil = false},
	},
},
[20] = { name="Magic Player Rewards",
	foil="y",
	cardcount={ reg=53, tok=24, nontr=0, overs=10 }, 
	variants={
["Bear"] 							= { "Bear"		, { "ONS", "ODY" } },
["Bear (ONS)"] 						= { "Bear"		, { "ONS", false } },
["Bear (ODY)"] 						= { "Bear"		, { false, "ODY" } },
["Beast"] 							= { "Beast"		, { "DST", "ODY" } },
["Beast (DST)"] 					= { "Beast"		, { "DST", false } },
["Beast (ODY)"] 					= { "Beast"		, { false, "ODY" } },
["Elephant"] 						= { "Elephant"	, { "INV", "ODY" } },
["Elephant (INV)"]					= { "Elephant"	, { "INV", false } },
["Elephant (ODY)"]					= { "Elephant"	, { false, "ODY" } },
["Spirit"] 							= { "Spirit"	, { "CHK", "PLS" } },
["Spirit (CHK)"] 					= { "Spirit"	, { "CHK", false } },
["Spirit (PLS)"] 					= { "Spirit"	, { false, "PLS" } },
	},
	foiltweak={
["Lightning Bolt (146)"]		= { foil = false}, -- there's two 'Bolts here, one nofoil, one foilonly
["Lightning Bolt (1)"]			= { foil = true }, -- there's two 'Bolts here, one nofoil, one foilonly
["Cryptic Command"]				= { foil = true },
["Damnation"]					= { foil = true },
["Day of Judgment"]				= { foil = true },
["Hypnotic Specter"]			= { foil = true },
["Powder Keg"]					= { foil = true },
["Psychatog"]					= { foil = true },
["Wasteland"]					= { foil = true },
["Wrath of God"]				= { foil = true },
	},
},
[15] = { name="Convention Promos",
	foilonly=true,
	cardcount={ reg=5, tok=0, nontr=0, overs=2 }, 
	foiltweak={
["Hurloon Minotaur"]			= { foil = false},
["Serra Angel"]					= { foil = false},
	},
},
[12] = { name="Hobby Japan Commemorative Cards",
--TODO [12]
--	foil="n",
--	cardcount={ reg=0, tok=0, nontr=0, overs=0 }, 
--	--jpn only
},
[11] = { name="Redemption Program Cards",
--TODO [11]
--	foil="n",
--	cardcount={ reg=0, tok=0, nontr=0, overs=0 }, 
--	--jpn only
},
[10] = { name="Junior Series Promos",
	foilonly=true,
	cardcount={ reg=31, tok=0, nontr=0, overs=0 }, 
	variants={
["Elvish Champion (E)"]				= {	"Elvish Champion"	, { "E"	, false , false } },
["Elvish Champion (J)"]				= {	"Elvish Champion"	, { false , false , "J" } },
["Glorious Anthem (E)"]				= {	"Glorious Anthem"	, { "E"	, false , false } },
["Glorious Anthem (U)"]				= {	"Glorious Anthem"	, { false , "U"	, false } },
["Glorious Anthem (J)"]				= {	"Glorious Anthem"	, { false , false , "J" } },
["Royal Assassin (E)"]				= {	"Royal Assassin"	, { "E"	, false , false } },
["Royal Assassin (J)"]				= {	"Royal Assassin"	, { false , false , "J" } },
["Sakura-Tribe Elder (E)"]			= {	"Sakura-Tribe Elder", { "E"	, false , false } },
["Sakura-Tribe Elder (U)"]			= {	"Sakura-Tribe Elder", { false , "U"	, false } },
["Sakura-Tribe Elder (J)"]			= {	"Sakura-Tribe Elder", { false , false , "J" } },
["Shard Phoenix (E)"]				= {	"Shard Phoenix"		, { "E"	, false , false } },
["Shard Phoenix (U)"]				= {	"Shard Phoenix"		, { false , "U"	, false } },
["Shard Phoenix (J)"]				= {	"Shard Phoenix"		, { false , false , "J" } },
["Slith Firewalker (E)"]			= {	"Slith Firewalker"	, { "E"	, false , false } },
["Slith Firewalker (J)"]			= {	"Slith Firewalker"	, { false , false , "J" } },
["Soltari Priest (U)"]				= {	"Soltari Priest"	, { false , "U"	, false } },
["Soltari Priest (J)"]				= {	"Soltari Priest"	, { false , false , "J" } },
["Soltari Priest (E)"]				= {	"Soltari Priest"	, { "E"	, false , false } },
["Whirling Dervish (E)"]			= {	"Whirling Dervish"	, { "E"	, false , false } },
["Whirling Dervish (U)"]			= {	"Whirling Dervish"	, { false , "U"	, false } },
["Whirling Dervish (J)"]			= {	"Whirling Dervish"	, { false , false , "J" } },
	},
},
[9] = { name="Video Game Promos",
	foilonly=true,
	cardcount={ reg=12, tok=0, nontr=0, overs=1 }, 
	foiltweak={
["Aswan Jaguar"] 				= { foil = false},
["Primordial Hydra"]			= { foil = false},
["Serra Avatar"] 				= { foil = false},
["Vampire Nocturnus"]			= { foil = false},
	},
},
[8] = { name="Stores Promos",
	foilonly=true,
	cardcount={ reg=9, tok=0, nontr=0, overs=0 }, 
},
[7] = { name="Magazine Inserts",
	foil="n",
	cardcount={ reg=7, tok=0, nontr=0, overs=5 }, 
	foiltweak={
["Lightning Hounds"]	 		= { foil = true },
["Warmonger"]					= { foil = true },
	},
},
[6] = { name="Comic Inserts",
	foil="n",
	cardcount={ reg=14, tok=0, nontr=0, overs=1 }, 
},
[5] = { name="Book Inserts",
	foil="n",
	cardcount={ reg=6, tok=0, nontr=0, overs=0 }, 
},
[4] = { name="Ultra Rare Cards",
	foil="n",
	cardcount={ reg=5, tok=0, nontr=0, overs=0 }, 
},
[2] = { name="DCI Legend Membership",
	foil="n",
	cardcount={ reg=2, tok=0, nontr=0, overs=0 }, 
},
[0] = { name="fakeset for Debug",
	variants={
["data"]			= { "inDataOnly"		, { "one", "two" } },
["data (1)"]		= { "inDataOnly"		, { "one", false } },
["data (2)"]		= { "inDataOnly"		, { false, "two" } },
["same"]			= { "samefromData"		, { "one", "two" } },
["same (1)"]		= { "samefromData"		, { "one", false } },
["same (2)"]		= { "samefromData"		, { false, "two" } },
	},
},
	
}-- end table Data.sets

for sid,set in pairs(Data.sets) do
	if set.cardcount then
		set.cardcount.both = set.cardcount.reg + set.cardcount.tok
	end --if
end -- for sid,count

--LHpi.Log( "LHpi.Data loaded and executed successfully." , 0 , nil , 0 )
ma.Log( "LHpi.Data loaded and executed successfully." , 0 , nil , 0 )
return Data
--EOF